// Code generated by 'yaegi extract syscall'. DO NOT EDIT.

//go:build go1.21 && !go1.22
// +build go1.21,!go1.22

package syscall

import (
	"go/constant"
	"go/token"
	"reflect"
	"syscall"
)

func init() {
	Symbols["syscall/syscall"] = map[string]reflect.Value{
		// function, constant and variable definitions
		"AF_APPLETALK":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"AF_ARP":                            reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"AF_ATM":                            reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"AF_BLUETOOTH":                      reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"AF_CCITT":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"AF_CHAOS":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"AF_CNT":                            reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"AF_COIP":                           reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"AF_DATAKIT":                        reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"AF_DECnet":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"AF_DLI":                            reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"AF_E164":                           reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"AF_ECMA":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"AF_HYLINK":                         reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"AF_IEEE80211":                      reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"AF_IMPLINK":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"AF_INET":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"AF_INET6":                          reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"AF_INET6_SDP":                      reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"AF_INET_SDP":                       reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"AF_IPX":                            reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"AF_ISDN":                           reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"AF_ISO":                            reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_LAT":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"AF_LINK":                           reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"AF_LOCAL":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_MAX":                            reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"AF_NATM":                           reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"AF_NETBIOS":                        reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"AF_NETGRAPH":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"AF_OSI":                            reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"AF_PUP":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"AF_ROUTE":                          reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"AF_SCLUSTER":                       reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"AF_SIP":                            reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"AF_SLOW":                           reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"AF_SNA":                            reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"AF_UNIX":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"AF_UNSPEC":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"AF_VENDOR00":                       reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"AF_VENDOR01":                       reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"AF_VENDOR02":                       reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"AF_VENDOR03":                       reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"AF_VENDOR04":                       reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"AF_VENDOR05":                       reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"AF_VENDOR06":                       reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"AF_VENDOR07":                       reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"AF_VENDOR08":                       reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"AF_VENDOR09":                       reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"AF_VENDOR10":                       reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"AF_VENDOR11":                       reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"AF_VENDOR12":                       reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"AF_VENDOR13":                       reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"AF_VENDOR14":                       reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"AF_VENDOR15":                       reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"AF_VENDOR16":                       reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"AF_VENDOR17":                       reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"AF_VENDOR18":                       reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"AF_VENDOR19":                       reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"AF_VENDOR20":                       reflect.ValueOf(constant.MakeFromLiteral("79", token.INT, 0)),
		"AF_VENDOR21":                       reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"AF_VENDOR22":                       reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"AF_VENDOR23":                       reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"AF_VENDOR24":                       reflect.ValueOf(constant.MakeFromLiteral("87", token.INT, 0)),
		"AF_VENDOR25":                       reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"AF_VENDOR26":                       reflect.ValueOf(constant.MakeFromLiteral("91", token.INT, 0)),
		"AF_VENDOR27":                       reflect.ValueOf(constant.MakeFromLiteral("93", token.INT, 0)),
		"AF_VENDOR28":                       reflect.ValueOf(constant.MakeFromLiteral("95", token.INT, 0)),
		"AF_VENDOR29":                       reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"AF_VENDOR30":                       reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"AF_VENDOR31":                       reflect.ValueOf(constant.MakeFromLiteral("101", token.INT, 0)),
		"AF_VENDOR32":                       reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"AF_VENDOR33":                       reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"AF_VENDOR34":                       reflect.ValueOf(constant.MakeFromLiteral("107", token.INT, 0)),
		"AF_VENDOR35":                       reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"AF_VENDOR36":                       reflect.ValueOf(constant.MakeFromLiteral("111", token.INT, 0)),
		"AF_VENDOR37":                       reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"AF_VENDOR38":                       reflect.ValueOf(constant.MakeFromLiteral("115", token.INT, 0)),
		"AF_VENDOR39":                       reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"AF_VENDOR40":                       reflect.ValueOf(constant.MakeFromLiteral("119", token.INT, 0)),
		"AF_VENDOR41":                       reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"AF_VENDOR42":                       reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"AF_VENDOR43":                       reflect.ValueOf(constant.MakeFromLiteral("125", token.INT, 0)),
		"AF_VENDOR44":                       reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"AF_VENDOR45":                       reflect.ValueOf(constant.MakeFromLiteral("129", token.INT, 0)),
		"AF_VENDOR46":                       reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"AF_VENDOR47":                       reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"Accept":                            reflect.ValueOf(syscall.Accept),
		"Accept4":                           reflect.ValueOf(syscall.Accept4),
		"Access":                            reflect.ValueOf(syscall.Access),
		"Adjtime":                           reflect.ValueOf(syscall.Adjtime),
		"B0":                                reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"B110":                              reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"B115200":                           reflect.ValueOf(constant.MakeFromLiteral("115200", token.INT, 0)),
		"B1200":                             reflect.ValueOf(constant.MakeFromLiteral("1200", token.INT, 0)),
		"B134":                              reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"B14400":                            reflect.ValueOf(constant.MakeFromLiteral("14400", token.INT, 0)),
		"B150":                              reflect.ValueOf(constant.MakeFromLiteral("150", token.INT, 0)),
		"B1800":                             reflect.ValueOf(constant.MakeFromLiteral("1800", token.INT, 0)),
		"B19200":                            reflect.ValueOf(constant.MakeFromLiteral("19200", token.INT, 0)),
		"B200":                              reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"B230400":                           reflect.ValueOf(constant.MakeFromLiteral("230400", token.INT, 0)),
		"B2400":                             reflect.ValueOf(constant.MakeFromLiteral("2400", token.INT, 0)),
		"B28800":                            reflect.ValueOf(constant.MakeFromLiteral("28800", token.INT, 0)),
		"B300":                              reflect.ValueOf(constant.MakeFromLiteral("300", token.INT, 0)),
		"B38400":                            reflect.ValueOf(constant.MakeFromLiteral("38400", token.INT, 0)),
		"B460800":                           reflect.ValueOf(constant.MakeFromLiteral("460800", token.INT, 0)),
		"B4800":                             reflect.ValueOf(constant.MakeFromLiteral("4800", token.INT, 0)),
		"B50":                               reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"B57600":                            reflect.ValueOf(constant.MakeFromLiteral("57600", token.INT, 0)),
		"B600":                              reflect.ValueOf(constant.MakeFromLiteral("600", token.INT, 0)),
		"B7200":                             reflect.ValueOf(constant.MakeFromLiteral("7200", token.INT, 0)),
		"B75":                               reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"B76800":                            reflect.ValueOf(constant.MakeFromLiteral("76800", token.INT, 0)),
		"B921600":                           reflect.ValueOf(constant.MakeFromLiteral("921600", token.INT, 0)),
		"B9600":                             reflect.ValueOf(constant.MakeFromLiteral("9600", token.INT, 0)),
		"BIOCFEEDBACK":                      reflect.ValueOf(constant.MakeFromLiteral("2147762812", token.INT, 0)),
		"BIOCFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("536887912", token.INT, 0)),
		"BIOCGBLEN":                         reflect.ValueOf(constant.MakeFromLiteral("1074020966", token.INT, 0)),
		"BIOCGDIRECTION":                    reflect.ValueOf(constant.MakeFromLiteral("1074020982", token.INT, 0)),
		"BIOCGDLT":                          reflect.ValueOf(constant.MakeFromLiteral("1074020970", token.INT, 0)),
		"BIOCGDLTLIST":                      reflect.ValueOf(constant.MakeFromLiteral("3222291065", token.INT, 0)),
		"BIOCGETBUFMODE":                    reflect.ValueOf(constant.MakeFromLiteral("1074020989", token.INT, 0)),
		"BIOCGETIF":                         reflect.ValueOf(constant.MakeFromLiteral("1075855979", token.INT, 0)),
		"BIOCGETZMAX":                       reflect.ValueOf(constant.MakeFromLiteral("1074283135", token.INT, 0)),
		"BIOCGHDRCMPLT":                     reflect.ValueOf(constant.MakeFromLiteral("1074020980", token.INT, 0)),
		"BIOCGRSIG":                         reflect.ValueOf(constant.MakeFromLiteral("1074020978", token.INT, 0)),
		"BIOCGRTIMEOUT":                     reflect.ValueOf(constant.MakeFromLiteral("1074807406", token.INT, 0)),
		"BIOCGSEESENT":                      reflect.ValueOf(constant.MakeFromLiteral("1074020982", token.INT, 0)),
		"BIOCGSTATS":                        reflect.ValueOf(constant.MakeFromLiteral("1074283119", token.INT, 0)),
		"BIOCGTSTAMP":                       reflect.ValueOf(constant.MakeFromLiteral("1074020995", token.INT, 0)),
		"BIOCIMMEDIATE":                     reflect.ValueOf(constant.MakeFromLiteral("2147762800", token.INT, 0)),
		"BIOCLOCK":                          reflect.ValueOf(constant.MakeFromLiteral("536887930", token.INT, 0)),
		"BIOCPROMISC":                       reflect.ValueOf(constant.MakeFromLiteral("536887913", token.INT, 0)),
		"BIOCROTZBUF":                       reflect.ValueOf(constant.MakeFromLiteral("1075331712", token.INT, 0)),
		"BIOCSBLEN":                         reflect.ValueOf(constant.MakeFromLiteral("3221504614", token.INT, 0)),
		"BIOCSDIRECTION":                    reflect.ValueOf(constant.MakeFromLiteral("2147762807", token.INT, 0)),
		"BIOCSDLT":                          reflect.ValueOf(constant.MakeFromLiteral("2147762808", token.INT, 0)),
		"BIOCSETBUFMODE":                    reflect.ValueOf(constant.MakeFromLiteral("2147762814", token.INT, 0)),
		"BIOCSETF":                          reflect.ValueOf(constant.MakeFromLiteral("2148549223", token.INT, 0)),
		"BIOCSETFNR":                        reflect.ValueOf(constant.MakeFromLiteral("2148549250", token.INT, 0)),
		"BIOCSETIF":                         reflect.ValueOf(constant.MakeFromLiteral("2149597804", token.INT, 0)),
		"BIOCSETWF":                         reflect.ValueOf(constant.MakeFromLiteral("2148549243", token.INT, 0)),
		"BIOCSETZBUF":                       reflect.ValueOf(constant.MakeFromLiteral("2149073537", token.INT, 0)),
		"BIOCSHDRCMPLT":                     reflect.ValueOf(constant.MakeFromLiteral("2147762805", token.INT, 0)),
		"BIOCSRSIG":                         reflect.ValueOf(constant.MakeFromLiteral("2147762803", token.INT, 0)),
		"BIOCSRTIMEOUT":                     reflect.ValueOf(constant.MakeFromLiteral("2148549229", token.INT, 0)),
		"BIOCSSEESENT":                      reflect.ValueOf(constant.MakeFromLiteral("2147762807", token.INT, 0)),
		"BIOCSTSTAMP":                       reflect.ValueOf(constant.MakeFromLiteral("2147762820", token.INT, 0)),
		"BIOCVERSION":                       reflect.ValueOf(constant.MakeFromLiteral("1074020977", token.INT, 0)),
		"BPF_A":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_ABS":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_ADD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_ALIGNMENT":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BPF_ALU":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"BPF_AND":                           reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"BPF_B":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_BUFMODE_BUFFER":                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_BUFMODE_ZBUF":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"BPF_DIV":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_H":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BPF_IMM":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_IND":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_JA":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_JEQ":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_JGE":                           reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"BPF_JGT":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_JMP":                           reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"BPF_JSET":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_K":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LD":                            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_LDX":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_LEN":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_LSH":                           reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MAJOR_VERSION":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MAXBUFSIZE":                    reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"BPF_MAXINSNS":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"BPF_MEM":                           reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"BPF_MEMWORDS":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_MINBUFSIZE":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_MINOR_VERSION":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_MISC":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"BPF_MSH":                           reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"BPF_MUL":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"BPF_NEG":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_OR":                            reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"BPF_RELEASE":                       reflect.ValueOf(constant.MakeFromLiteral("199606", token.INT, 0)),
		"BPF_RET":                           reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"BPF_RSH":                           reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"BPF_ST":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"BPF_STX":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"BPF_SUB":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"BPF_TAX":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_TXA":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"BPF_T_BINTIME":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"BPF_T_BINTIME_FAST":                reflect.ValueOf(constant.MakeFromLiteral("258", token.INT, 0)),
		"BPF_T_BINTIME_MONOTONIC":           reflect.ValueOf(constant.MakeFromLiteral("514", token.INT, 0)),
		"BPF_T_BINTIME_MONOTONIC_FAST":      reflect.ValueOf(constant.MakeFromLiteral("770", token.INT, 0)),
		"BPF_T_FAST":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"BPF_T_FLAG_MASK":                   reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"BPF_T_FORMAT_MASK":                 reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"BPF_T_MICROTIME":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_T_MICROTIME_FAST":              reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"BPF_T_MICROTIME_MONOTONIC":         reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"BPF_T_MICROTIME_MONOTONIC_FAST":    reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"BPF_T_MONOTONIC":                   reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"BPF_T_MONOTONIC_FAST":              reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"BPF_T_NANOTIME":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"BPF_T_NANOTIME_FAST":               reflect.ValueOf(constant.MakeFromLiteral("257", token.INT, 0)),
		"BPF_T_NANOTIME_MONOTONIC":          reflect.ValueOf(constant.MakeFromLiteral("513", token.INT, 0)),
		"BPF_T_NANOTIME_MONOTONIC_FAST":     reflect.ValueOf(constant.MakeFromLiteral("769", token.INT, 0)),
		"BPF_T_NONE":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"BPF_T_NORMAL":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_W":                             reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"BPF_X":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"BRKINT":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Bind":                              reflect.ValueOf(syscall.Bind),
		"BpfBuflen":                         reflect.ValueOf(syscall.BpfBuflen),
		"BpfDatalink":                       reflect.ValueOf(syscall.BpfDatalink),
		"BpfHeadercmpl":                     reflect.ValueOf(syscall.BpfHeadercmpl),
		"BpfInterface":                      reflect.ValueOf(syscall.BpfInterface),
		"BpfJump":                           reflect.ValueOf(syscall.BpfJump),
		"BpfStats":                          reflect.ValueOf(syscall.BpfStats),
		"BpfStmt":                           reflect.ValueOf(syscall.BpfStmt),
		"BpfTimeout":                        reflect.ValueOf(syscall.BpfTimeout),
		"BytePtrFromString":                 reflect.ValueOf(syscall.BytePtrFromString),
		"ByteSliceFromString":               reflect.ValueOf(syscall.ByteSliceFromString),
		"CFLUSH":                            reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"CLOCAL":                            reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"CREAD":                             reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"CS5":                               reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"CS6":                               reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"CS7":                               reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"CS8":                               reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"CSIZE":                             reflect.ValueOf(constant.MakeFromLiteral("768", token.INT, 0)),
		"CSTART":                            reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"CSTATUS":                           reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"CSTOP":                             reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"CSTOPB":                            reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"CSUSP":                             reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"CTL_MAXNAME":                       reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"CTL_NET":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"Chdir":                             reflect.ValueOf(syscall.Chdir),
		"CheckBpfVersion":                   reflect.ValueOf(syscall.CheckBpfVersion),
		"Chflags":                           reflect.ValueOf(syscall.Chflags),
		"Chmod":                             reflect.ValueOf(syscall.Chmod),
		"Chown":                             reflect.ValueOf(syscall.Chown),
		"Chroot":                            reflect.ValueOf(syscall.Chroot),
		"Clearenv":                          reflect.ValueOf(syscall.Clearenv),
		"Close":                             reflect.ValueOf(syscall.Close),
		"CloseOnExec":                       reflect.ValueOf(syscall.CloseOnExec),
		"CmsgLen":                           reflect.ValueOf(syscall.CmsgLen),
		"CmsgSpace":                         reflect.ValueOf(syscall.CmsgSpace),
		"Connect":                           reflect.ValueOf(syscall.Connect),
		"DLT_A429":                          reflect.ValueOf(constant.MakeFromLiteral("184", token.INT, 0)),
		"DLT_A653_ICM":                      reflect.ValueOf(constant.MakeFromLiteral("185", token.INT, 0)),
		"DLT_AIRONET_HEADER":                reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"DLT_AOS":                           reflect.ValueOf(constant.MakeFromLiteral("222", token.INT, 0)),
		"DLT_APPLE_IP_OVER_IEEE1394":        reflect.ValueOf(constant.MakeFromLiteral("138", token.INT, 0)),
		"DLT_ARCNET":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"DLT_ARCNET_LINUX":                  reflect.ValueOf(constant.MakeFromLiteral("129", token.INT, 0)),
		"DLT_ATM_CLIP":                      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"DLT_ATM_RFC1483":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"DLT_AURORA":                        reflect.ValueOf(constant.MakeFromLiteral("126", token.INT, 0)),
		"DLT_AX25":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"DLT_AX25_KISS":                     reflect.ValueOf(constant.MakeFromLiteral("202", token.INT, 0)),
		"DLT_BACNET_MS_TP":                  reflect.ValueOf(constant.MakeFromLiteral("165", token.INT, 0)),
		"DLT_BLUETOOTH_HCI_H4":              reflect.ValueOf(constant.MakeFromLiteral("187", token.INT, 0)),
		"DLT_BLUETOOTH_HCI_H4_WITH_PHDR":    reflect.ValueOf(constant.MakeFromLiteral("201", token.INT, 0)),
		"DLT_CAN20B":                        reflect.ValueOf(constant.MakeFromLiteral("190", token.INT, 0)),
		"DLT_CAN_SOCKETCAN":                 reflect.ValueOf(constant.MakeFromLiteral("227", token.INT, 0)),
		"DLT_CHAOS":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"DLT_CHDLC":                         reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"DLT_CISCO_IOS":                     reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"DLT_C_HDLC":                        reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"DLT_C_HDLC_WITH_DIR":               reflect.ValueOf(constant.MakeFromLiteral("205", token.INT, 0)),
		"DLT_DBUS":                          reflect.ValueOf(constant.MakeFromLiteral("231", token.INT, 0)),
		"DLT_DECT":                          reflect.ValueOf(constant.MakeFromLiteral("221", token.INT, 0)),
		"DLT_DOCSIS":                        reflect.ValueOf(constant.MakeFromLiteral("143", token.INT, 0)),
		"DLT_DVB_CI":                        reflect.ValueOf(constant.MakeFromLiteral("235", token.INT, 0)),
		"DLT_ECONET":                        reflect.ValueOf(constant.MakeFromLiteral("115", token.INT, 0)),
		"DLT_EN10MB":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DLT_EN3MB":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DLT_ENC":                           reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"DLT_ERF":                           reflect.ValueOf(constant.MakeFromLiteral("197", token.INT, 0)),
		"DLT_ERF_ETH":                       reflect.ValueOf(constant.MakeFromLiteral("175", token.INT, 0)),
		"DLT_ERF_POS":                       reflect.ValueOf(constant.MakeFromLiteral("176", token.INT, 0)),
		"DLT_FC_2":                          reflect.ValueOf(constant.MakeFromLiteral("224", token.INT, 0)),
		"DLT_FC_2_WITH_FRAME_DELIMS":        reflect.ValueOf(constant.MakeFromLiteral("225", token.INT, 0)),
		"DLT_FDDI":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"DLT_FLEXRAY":                       reflect.ValueOf(constant.MakeFromLiteral("210", token.INT, 0)),
		"DLT_FRELAY":                        reflect.ValueOf(constant.MakeFromLiteral("107", token.INT, 0)),
		"DLT_FRELAY_WITH_DIR":               reflect.ValueOf(constant.MakeFromLiteral("206", token.INT, 0)),
		"DLT_GCOM_SERIAL":                   reflect.ValueOf(constant.MakeFromLiteral("173", token.INT, 0)),
		"DLT_GCOM_T1E1":                     reflect.ValueOf(constant.MakeFromLiteral("172", token.INT, 0)),
		"DLT_GPF_F":                         reflect.ValueOf(constant.MakeFromLiteral("171", token.INT, 0)),
		"DLT_GPF_T":                         reflect.ValueOf(constant.MakeFromLiteral("170", token.INT, 0)),
		"DLT_GPRS_LLC":                      reflect.ValueOf(constant.MakeFromLiteral("169", token.INT, 0)),
		"DLT_GSMTAP_ABIS":                   reflect.ValueOf(constant.MakeFromLiteral("218", token.INT, 0)),
		"DLT_GSMTAP_UM":                     reflect.ValueOf(constant.MakeFromLiteral("217", token.INT, 0)),
		"DLT_HHDLC":                         reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"DLT_IBM_SN":                        reflect.ValueOf(constant.MakeFromLiteral("146", token.INT, 0)),
		"DLT_IBM_SP":                        reflect.ValueOf(constant.MakeFromLiteral("145", token.INT, 0)),
		"DLT_IEEE802":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"DLT_IEEE802_11":                    reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"DLT_IEEE802_11_RADIO":              reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"DLT_IEEE802_11_RADIO_AVS":          reflect.ValueOf(constant.MakeFromLiteral("163", token.INT, 0)),
		"DLT_IEEE802_15_4":                  reflect.ValueOf(constant.MakeFromLiteral("195", token.INT, 0)),
		"DLT_IEEE802_15_4_LINUX":            reflect.ValueOf(constant.MakeFromLiteral("191", token.INT, 0)),
		"DLT_IEEE802_15_4_NOFCS":            reflect.ValueOf(constant.MakeFromLiteral("230", token.INT, 0)),
		"DLT_IEEE802_15_4_NONASK_PHY":       reflect.ValueOf(constant.MakeFromLiteral("215", token.INT, 0)),
		"DLT_IEEE802_16_MAC_CPS":            reflect.ValueOf(constant.MakeFromLiteral("188", token.INT, 0)),
		"DLT_IEEE802_16_MAC_CPS_RADIO":      reflect.ValueOf(constant.MakeFromLiteral("193", token.INT, 0)),
		"DLT_IPFILTER":                      reflect.ValueOf(constant.MakeFromLiteral("116", token.INT, 0)),
		"DLT_IPMB":                          reflect.ValueOf(constant.MakeFromLiteral("199", token.INT, 0)),
		"DLT_IPMB_LINUX":                    reflect.ValueOf(constant.MakeFromLiteral("209", token.INT, 0)),
		"DLT_IPNET":                         reflect.ValueOf(constant.MakeFromLiteral("226", token.INT, 0)),
		"DLT_IPOIB":                         reflect.ValueOf(constant.MakeFromLiteral("242", token.INT, 0)),
		"DLT_IPV4":                          reflect.ValueOf(constant.MakeFromLiteral("228", token.INT, 0)),
		"DLT_IPV6":                          reflect.ValueOf(constant.MakeFromLiteral("229", token.INT, 0)),
		"DLT_IP_OVER_FC":                    reflect.ValueOf(constant.MakeFromLiteral("122", token.INT, 0)),
		"DLT_JUNIPER_ATM1":                  reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"DLT_JUNIPER_ATM2":                  reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"DLT_JUNIPER_ATM_CEMIC":             reflect.ValueOf(constant.MakeFromLiteral("238", token.INT, 0)),
		"DLT_JUNIPER_CHDLC":                 reflect.ValueOf(constant.MakeFromLiteral("181", token.INT, 0)),
		"DLT_JUNIPER_ES":                    reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"DLT_JUNIPER_ETHER":                 reflect.ValueOf(constant.MakeFromLiteral("178", token.INT, 0)),
		"DLT_JUNIPER_FIBRECHANNEL":          reflect.ValueOf(constant.MakeFromLiteral("234", token.INT, 0)),
		"DLT_JUNIPER_FRELAY":                reflect.ValueOf(constant.MakeFromLiteral("180", token.INT, 0)),
		"DLT_JUNIPER_GGSN":                  reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"DLT_JUNIPER_ISM":                   reflect.ValueOf(constant.MakeFromLiteral("194", token.INT, 0)),
		"DLT_JUNIPER_MFR":                   reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"DLT_JUNIPER_MLFR":                  reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"DLT_JUNIPER_MLPPP":                 reflect.ValueOf(constant.MakeFromLiteral("130", token.INT, 0)),
		"DLT_JUNIPER_MONITOR":               reflect.ValueOf(constant.MakeFromLiteral("164", token.INT, 0)),
		"DLT_JUNIPER_PIC_PEER":              reflect.ValueOf(constant.MakeFromLiteral("174", token.INT, 0)),
		"DLT_JUNIPER_PPP":                   reflect.ValueOf(constant.MakeFromLiteral("179", token.INT, 0)),
		"DLT_JUNIPER_PPPOE":                 reflect.ValueOf(constant.MakeFromLiteral("167", token.INT, 0)),
		"DLT_JUNIPER_PPPOE_ATM":             reflect.ValueOf(constant.MakeFromLiteral("168", token.INT, 0)),
		"DLT_JUNIPER_SERVICES":              reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"DLT_JUNIPER_SRX_E2E":               reflect.ValueOf(constant.MakeFromLiteral("233", token.INT, 0)),
		"DLT_JUNIPER_ST":                    reflect.ValueOf(constant.MakeFromLiteral("200", token.INT, 0)),
		"DLT_JUNIPER_VP":                    reflect.ValueOf(constant.MakeFromLiteral("183", token.INT, 0)),
		"DLT_JUNIPER_VS":                    reflect.ValueOf(constant.MakeFromLiteral("232", token.INT, 0)),
		"DLT_LAPB_WITH_DIR":                 reflect.ValueOf(constant.MakeFromLiteral("207", token.INT, 0)),
		"DLT_LAPD":                          reflect.ValueOf(constant.MakeFromLiteral("203", token.INT, 0)),
		"DLT_LIN":                           reflect.ValueOf(constant.MakeFromLiteral("212", token.INT, 0)),
		"DLT_LINUX_EVDEV":                   reflect.ValueOf(constant.MakeFromLiteral("216", token.INT, 0)),
		"DLT_LINUX_IRDA":                    reflect.ValueOf(constant.MakeFromLiteral("144", token.INT, 0)),
		"DLT_LINUX_LAPD":                    reflect.ValueOf(constant.MakeFromLiteral("177", token.INT, 0)),
		"DLT_LINUX_PPP_WITHDIRECTION":       reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"DLT_LINUX_SLL":                     reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"DLT_LOOP":                          reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"DLT_LTALK":                         reflect.ValueOf(constant.MakeFromLiteral("114", token.INT, 0)),
		"DLT_MATCHING_MAX":                  reflect.ValueOf(constant.MakeFromLiteral("246", token.INT, 0)),
		"DLT_MATCHING_MIN":                  reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"DLT_MFR":                           reflect.ValueOf(constant.MakeFromLiteral("182", token.INT, 0)),
		"DLT_MOST":                          reflect.ValueOf(constant.MakeFromLiteral("211", token.INT, 0)),
		"DLT_MPEG_2_TS":                     reflect.ValueOf(constant.MakeFromLiteral("243", token.INT, 0)),
		"DLT_MPLS":                          reflect.ValueOf(constant.MakeFromLiteral("219", token.INT, 0)),
		"DLT_MTP2":                          reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"DLT_MTP2_WITH_PHDR":                reflect.ValueOf(constant.MakeFromLiteral("139", token.INT, 0)),
		"DLT_MTP3":                          reflect.ValueOf(constant.MakeFromLiteral("141", token.INT, 0)),
		"DLT_MUX27010":                      reflect.ValueOf(constant.MakeFromLiteral("236", token.INT, 0)),
		"DLT_NETANALYZER":                   reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"DLT_NETANALYZER_TRANSPARENT":       reflect.ValueOf(constant.MakeFromLiteral("241", token.INT, 0)),
		"DLT_NFC_LLCP":                      reflect.ValueOf(constant.MakeFromLiteral("245", token.INT, 0)),
		"DLT_NFLOG":                         reflect.ValueOf(constant.MakeFromLiteral("239", token.INT, 0)),
		"DLT_NG40":                          reflect.ValueOf(constant.MakeFromLiteral("244", token.INT, 0)),
		"DLT_NULL":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"DLT_PCI_EXP":                       reflect.ValueOf(constant.MakeFromLiteral("125", token.INT, 0)),
		"DLT_PFLOG":                         reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"DLT_PFSYNC":                        reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"DLT_PPI":                           reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"DLT_PPP":                           reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"DLT_PPP_BSDOS":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"DLT_PPP_ETHER":                     reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"DLT_PPP_PPPD":                      reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"DLT_PPP_SERIAL":                    reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"DLT_PPP_WITH_DIR":                  reflect.ValueOf(constant.MakeFromLiteral("204", token.INT, 0)),
		"DLT_PPP_WITH_DIRECTION":            reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"DLT_PRISM_HEADER":                  reflect.ValueOf(constant.MakeFromLiteral("119", token.INT, 0)),
		"DLT_PRONET":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"DLT_RAIF1":                         reflect.ValueOf(constant.MakeFromLiteral("198", token.INT, 0)),
		"DLT_RAW":                           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"DLT_RIO":                           reflect.ValueOf(constant.MakeFromLiteral("124", token.INT, 0)),
		"DLT_SCCP":                          reflect.ValueOf(constant.MakeFromLiteral("142", token.INT, 0)),
		"DLT_SITA":                          reflect.ValueOf(constant.MakeFromLiteral("196", token.INT, 0)),
		"DLT_SLIP":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"DLT_SLIP_BSDOS":                    reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"DLT_STANAG_5066_D_PDU":             reflect.ValueOf(constant.MakeFromLiteral("237", token.INT, 0)),
		"DLT_SUNATM":                        reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"DLT_SYMANTEC_FIREWALL":             reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"DLT_TZSP":                          reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"DLT_USB":                           reflect.ValueOf(constant.MakeFromLiteral("186", token.INT, 0)),
		"DLT_USB_LINUX":                     reflect.ValueOf(constant.MakeFromLiteral("189", token.INT, 0)),
		"DLT_USB_LINUX_MMAPPED":             reflect.ValueOf(constant.MakeFromLiteral("220", token.INT, 0)),
		"DLT_USER0":                         reflect.ValueOf(constant.MakeFromLiteral("147", token.INT, 0)),
		"DLT_USER1":                         reflect.ValueOf(constant.MakeFromLiteral("148", token.INT, 0)),
		"DLT_USER10":                        reflect.ValueOf(constant.MakeFromLiteral("157", token.INT, 0)),
		"DLT_USER11":                        reflect.ValueOf(constant.MakeFromLiteral("158", token.INT, 0)),
		"DLT_USER12":                        reflect.ValueOf(constant.MakeFromLiteral("159", token.INT, 0)),
		"DLT_USER13":                        reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"DLT_USER14":                        reflect.ValueOf(constant.MakeFromLiteral("161", token.INT, 0)),
		"DLT_USER15":                        reflect.ValueOf(constant.MakeFromLiteral("162", token.INT, 0)),
		"DLT_USER2":                         reflect.ValueOf(constant.MakeFromLiteral("149", token.INT, 0)),
		"DLT_USER3":                         reflect.ValueOf(constant.MakeFromLiteral("150", token.INT, 0)),
		"DLT_USER4":                         reflect.ValueOf(constant.MakeFromLiteral("151", token.INT, 0)),
		"DLT_USER5":                         reflect.ValueOf(constant.MakeFromLiteral("152", token.INT, 0)),
		"DLT_USER6":                         reflect.ValueOf(constant.MakeFromLiteral("153", token.INT, 0)),
		"DLT_USER7":                         reflect.ValueOf(constant.MakeFromLiteral("154", token.INT, 0)),
		"DLT_USER8":                         reflect.ValueOf(constant.MakeFromLiteral("155", token.INT, 0)),
		"DLT_USER9":                         reflect.ValueOf(constant.MakeFromLiteral("156", token.INT, 0)),
		"DLT_WIHART":                        reflect.ValueOf(constant.MakeFromLiteral("223", token.INT, 0)),
		"DLT_X2E_SERIAL":                    reflect.ValueOf(constant.MakeFromLiteral("213", token.INT, 0)),
		"DLT_X2E_XORAYA":                    reflect.ValueOf(constant.MakeFromLiteral("214", token.INT, 0)),
		"DT_BLK":                            reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"DT_CHR":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"DT_DIR":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"DT_FIFO":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"DT_LNK":                            reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"DT_REG":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"DT_SOCK":                           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"DT_UNKNOWN":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"DT_WHT":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"Dup":                               reflect.ValueOf(syscall.Dup),
		"Dup2":                              reflect.ValueOf(syscall.Dup2),
		"E2BIG":                             reflect.ValueOf(syscall.E2BIG),
		"EACCES":                            reflect.ValueOf(syscall.EACCES),
		"EADDRINUSE":                        reflect.ValueOf(syscall.EADDRINUSE),
		"EADDRNOTAVAIL":                     reflect.ValueOf(syscall.EADDRNOTAVAIL),
		"EAFNOSUPPORT":                      reflect.ValueOf(syscall.EAFNOSUPPORT),
		"EAGAIN":                            reflect.ValueOf(syscall.EAGAIN),
		"EALREADY":                          reflect.ValueOf(syscall.EALREADY),
		"EAUTH":                             reflect.ValueOf(syscall.EAUTH),
		"EBADF":                             reflect.ValueOf(syscall.EBADF),
		"EBADMSG":                           reflect.ValueOf(syscall.EBADMSG),
		"EBADRPC":                           reflect.ValueOf(syscall.EBADRPC),
		"EBUSY":                             reflect.ValueOf(syscall.EBUSY),
		"ECANCELED":                         reflect.ValueOf(syscall.ECANCELED),
		"ECAPMODE":                          reflect.ValueOf(syscall.ECAPMODE),
		"ECHILD":                            reflect.ValueOf(syscall.ECHILD),
		"ECHO":                              reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"ECHOCTL":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ECHOE":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ECHOK":                             reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"ECHOKE":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"ECHONL":                            reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ECHOPRT":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ECONNABORTED":                      reflect.ValueOf(syscall.ECONNABORTED),
		"ECONNREFUSED":                      reflect.ValueOf(syscall.ECONNREFUSED),
		"ECONNRESET":                        reflect.ValueOf(syscall.ECONNRESET),
		"EDEADLK":                           reflect.ValueOf(syscall.EDEADLK),
		"EDESTADDRREQ":                      reflect.ValueOf(syscall.EDESTADDRREQ),
		"EDOM":                              reflect.ValueOf(syscall.EDOM),
		"EDOOFUS":                           reflect.ValueOf(syscall.EDOOFUS),
		"EDQUOT":                            reflect.ValueOf(syscall.EDQUOT),
		"EEXIST":                            reflect.ValueOf(syscall.EEXIST),
		"EFAULT":                            reflect.ValueOf(syscall.EFAULT),
		"EFBIG":                             reflect.ValueOf(syscall.EFBIG),
		"EFTYPE":                            reflect.ValueOf(syscall.EFTYPE),
		"EHOSTDOWN":                         reflect.ValueOf(syscall.EHOSTDOWN),
		"EHOSTUNREACH":                      reflect.ValueOf(syscall.EHOSTUNREACH),
		"EIDRM":                             reflect.ValueOf(syscall.EIDRM),
		"EILSEQ":                            reflect.ValueOf(syscall.EILSEQ),
		"EINPROGRESS":                       reflect.ValueOf(syscall.EINPROGRESS),
		"EINTR":                             reflect.ValueOf(syscall.EINTR),
		"EINVAL":                            reflect.ValueOf(syscall.EINVAL),
		"EIO":                               reflect.ValueOf(syscall.EIO),
		"EISCONN":                           reflect.ValueOf(syscall.EISCONN),
		"EISDIR":                            reflect.ValueOf(syscall.EISDIR),
		"ELAST":                             reflect.ValueOf(syscall.ELAST),
		"ELOOP":                             reflect.ValueOf(syscall.ELOOP),
		"EMFILE":                            reflect.ValueOf(syscall.EMFILE),
		"EMLINK":                            reflect.ValueOf(syscall.EMLINK),
		"EMSGSIZE":                          reflect.ValueOf(syscall.EMSGSIZE),
		"EMULTIHOP":                         reflect.ValueOf(syscall.EMULTIHOP),
		"ENAMETOOLONG":                      reflect.ValueOf(syscall.ENAMETOOLONG),
		"ENEEDAUTH":                         reflect.ValueOf(syscall.ENEEDAUTH),
		"ENETDOWN":                          reflect.ValueOf(syscall.ENETDOWN),
		"ENETRESET":                         reflect.ValueOf(syscall.ENETRESET),
		"ENETUNREACH":                       reflect.ValueOf(syscall.ENETUNREACH),
		"ENFILE":                            reflect.ValueOf(syscall.ENFILE),
		"ENOATTR":                           reflect.ValueOf(syscall.ENOATTR),
		"ENOBUFS":                           reflect.ValueOf(syscall.ENOBUFS),
		"ENODEV":                            reflect.ValueOf(syscall.ENODEV),
		"ENOENT":                            reflect.ValueOf(syscall.ENOENT),
		"ENOEXEC":                           reflect.ValueOf(syscall.ENOEXEC),
		"ENOLCK":                            reflect.ValueOf(syscall.ENOLCK),
		"ENOLINK":                           reflect.ValueOf(syscall.ENOLINK),
		"ENOMEM":                            reflect.ValueOf(syscall.ENOMEM),
		"ENOMSG":                            reflect.ValueOf(syscall.ENOMSG),
		"ENOPROTOOPT":                       reflect.ValueOf(syscall.ENOPROTOOPT),
		"ENOSPC":                            reflect.ValueOf(syscall.ENOSPC),
		"ENOSYS":                            reflect.ValueOf(syscall.ENOSYS),
		"ENOTBLK":                           reflect.ValueOf(syscall.ENOTBLK),
		"ENOTCAPABLE":                       reflect.ValueOf(syscall.ENOTCAPABLE),
		"ENOTCONN":                          reflect.ValueOf(syscall.ENOTCONN),
		"ENOTDIR":                           reflect.ValueOf(syscall.ENOTDIR),
		"ENOTEMPTY":                         reflect.ValueOf(syscall.ENOTEMPTY),
		"ENOTRECOVERABLE":                   reflect.ValueOf(syscall.ENOTRECOVERABLE),
		"ENOTSOCK":                          reflect.ValueOf(syscall.ENOTSOCK),
		"ENOTSUP":                           reflect.ValueOf(syscall.ENOTSUP),
		"ENOTTY":                            reflect.ValueOf(syscall.ENOTTY),
		"ENXIO":                             reflect.ValueOf(syscall.ENXIO),
		"EOPNOTSUPP":                        reflect.ValueOf(syscall.EOPNOTSUPP),
		"EOVERFLOW":                         reflect.ValueOf(syscall.EOVERFLOW),
		"EOWNERDEAD":                        reflect.ValueOf(syscall.EOWNERDEAD),
		"EPERM":                             reflect.ValueOf(syscall.EPERM),
		"EPFNOSUPPORT":                      reflect.ValueOf(syscall.EPFNOSUPPORT),
		"EPIPE":                             reflect.ValueOf(syscall.EPIPE),
		"EPROCLIM":                          reflect.ValueOf(syscall.EPROCLIM),
		"EPROCUNAVAIL":                      reflect.ValueOf(syscall.EPROCUNAVAIL),
		"EPROGMISMATCH":                     reflect.ValueOf(syscall.EPROGMISMATCH),
		"EPROGUNAVAIL":                      reflect.ValueOf(syscall.EPROGUNAVAIL),
		"EPROTO":                            reflect.ValueOf(syscall.EPROTO),
		"EPROTONOSUPPORT":                   reflect.ValueOf(syscall.EPROTONOSUPPORT),
		"EPROTOTYPE":                        reflect.ValueOf(syscall.EPROTOTYPE),
		"ERANGE":                            reflect.ValueOf(syscall.ERANGE),
		"EREMOTE":                           reflect.ValueOf(syscall.EREMOTE),
		"EROFS":                             reflect.ValueOf(syscall.EROFS),
		"ERPCMISMATCH":                      reflect.ValueOf(syscall.ERPCMISMATCH),
		"ESHUTDOWN":                         reflect.ValueOf(syscall.ESHUTDOWN),
		"ESOCKTNOSUPPORT":                   reflect.ValueOf(syscall.ESOCKTNOSUPPORT),
		"ESPIPE":                            reflect.ValueOf(syscall.ESPIPE),
		"ESRCH":                             reflect.ValueOf(syscall.ESRCH),
		"ESTALE":                            reflect.ValueOf(syscall.ESTALE),
		"ETIMEDOUT":                         reflect.ValueOf(syscall.ETIMEDOUT),
		"ETOOMANYREFS":                      reflect.ValueOf(syscall.ETOOMANYREFS),
		"ETXTBSY":                           reflect.ValueOf(syscall.ETXTBSY),
		"EUSERS":                            reflect.ValueOf(syscall.EUSERS),
		"EVFILT_AIO":                        reflect.ValueOf(constant.MakeFromLiteral("-3", token.INT, 0)),
		"EVFILT_FS":                         reflect.ValueOf(constant.MakeFromLiteral("-9", token.INT, 0)),
		"EVFILT_LIO":                        reflect.ValueOf(constant.MakeFromLiteral("-10", token.INT, 0)),
		"EVFILT_PROC":                       reflect.ValueOf(constant.MakeFromLiteral("-5", token.INT, 0)),
		"EVFILT_READ":                       reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"EVFILT_SIGNAL":                     reflect.ValueOf(constant.MakeFromLiteral("-6", token.INT, 0)),
		"EVFILT_SYSCOUNT":                   reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"EVFILT_TIMER":                      reflect.ValueOf(constant.MakeFromLiteral("-7", token.INT, 0)),
		"EVFILT_USER":                       reflect.ValueOf(constant.MakeFromLiteral("-11", token.INT, 0)),
		"EVFILT_VNODE":                      reflect.ValueOf(constant.MakeFromLiteral("-4", token.INT, 0)),
		"EVFILT_WRITE":                      reflect.ValueOf(constant.MakeFromLiteral("-2", token.INT, 0)),
		"EV_ADD":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"EV_CLEAR":                          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"EV_DELETE":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"EV_DISABLE":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"EV_DISPATCH":                       reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"EV_DROP":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"EV_ENABLE":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"EV_EOF":                            reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"EV_ERROR":                          reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"EV_FLAG1":                          reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"EV_ONESHOT":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"EV_RECEIPT":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"EV_SYSFLAGS":                       reflect.ValueOf(constant.MakeFromLiteral("61440", token.INT, 0)),
		"EWOULDBLOCK":                       reflect.ValueOf(syscall.EWOULDBLOCK),
		"EXDEV":                             reflect.ValueOf(syscall.EXDEV),
		"EXTA":                              reflect.ValueOf(constant.MakeFromLiteral("19200", token.INT, 0)),
		"EXTB":                              reflect.ValueOf(constant.MakeFromLiteral("38400", token.INT, 0)),
		"EXTPROC":                           reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"Environ":                           reflect.ValueOf(syscall.Environ),
		"FD_CLOEXEC":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"FD_SETSIZE":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"FLUSHO":                            reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"F_CANCEL":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"F_DUP2FD":                          reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"F_DUP2FD_CLOEXEC":                  reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"F_DUPFD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_DUPFD_CLOEXEC":                   reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"F_GETFD":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_GETFL":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"F_GETLK":                           reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"F_GETOWN":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"F_OGETLK":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"F_OK":                              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"F_OSETLK":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"F_OSETLKW":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"F_RDAHEAD":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"F_RDLCK":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"F_READAHEAD":                       reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"F_SETFD":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_SETFL":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_SETLK":                           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"F_SETLKW":                          reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"F_SETLK_REMOTE":                    reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"F_SETOWN":                          reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"F_UNLCK":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"F_UNLCKSYS":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"F_WRLCK":                           reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"Fchdir":                            reflect.ValueOf(syscall.Fchdir),
		"Fchflags":                          reflect.ValueOf(syscall.Fchflags),
		"Fchmod":                            reflect.ValueOf(syscall.Fchmod),
		"Fchown":                            reflect.ValueOf(syscall.Fchown),
		"FcntlFlock":                        reflect.ValueOf(syscall.FcntlFlock),
		"Flock":                             reflect.ValueOf(syscall.Flock),
		"FlushBpf":                          reflect.ValueOf(syscall.FlushBpf),
		"ForkLock":                          reflect.ValueOf(&syscall.ForkLock).Elem(),
		"Fpathconf":                         reflect.ValueOf(syscall.Fpathconf),
		"Fstat":                             reflect.ValueOf(syscall.Fstat),
		"Fstatat":                           reflect.ValueOf(syscall.Fstatat),
		"Fstatfs":                           reflect.ValueOf(syscall.Fstatfs),
		"Fsync":                             reflect.ValueOf(syscall.Fsync),
		"Ftruncate":                         reflect.ValueOf(syscall.Ftruncate),
		"Futimes":                           reflect.ValueOf(syscall.Futimes),
		"Getdirentries":                     reflect.ValueOf(syscall.Getdirentries),
		"Getdtablesize":                     reflect.ValueOf(syscall.Getdtablesize),
		"Getegid":                           reflect.ValueOf(syscall.Getegid),
		"Getenv":                            reflect.ValueOf(syscall.Getenv),
		"Geteuid":                           reflect.ValueOf(syscall.Geteuid),
		"Getfsstat":                         reflect.ValueOf(syscall.Getfsstat),
		"Getgid":                            reflect.ValueOf(syscall.Getgid),
		"Getgroups":                         reflect.ValueOf(syscall.Getgroups),
		"Getpagesize":                       reflect.ValueOf(syscall.Getpagesize),
		"Getpeername":                       reflect.ValueOf(syscall.Getpeername),
		"Getpgid":                           reflect.ValueOf(syscall.Getpgid),
		"Getpgrp":                           reflect.ValueOf(syscall.Getpgrp),
		"Getpid":                            reflect.ValueOf(syscall.Getpid),
		"Getppid":                           reflect.ValueOf(syscall.Getppid),
		"Getpriority":                       reflect.ValueOf(syscall.Getpriority),
		"Getrlimit":                         reflect.ValueOf(syscall.Getrlimit),
		"Getrusage":                         reflect.ValueOf(syscall.Getrusage),
		"Getsid":                            reflect.ValueOf(syscall.Getsid),
		"Getsockname":                       reflect.ValueOf(syscall.Getsockname),
		"GetsockoptByte":                    reflect.ValueOf(syscall.GetsockoptByte),
		"GetsockoptICMPv6Filter":            reflect.ValueOf(syscall.GetsockoptICMPv6Filter),
		"GetsockoptIPMreq":                  reflect.ValueOf(syscall.GetsockoptIPMreq),
		"GetsockoptIPMreqn":                 reflect.ValueOf(syscall.GetsockoptIPMreqn),
		"GetsockoptIPv6MTUInfo":             reflect.ValueOf(syscall.GetsockoptIPv6MTUInfo),
		"GetsockoptIPv6Mreq":                reflect.ValueOf(syscall.GetsockoptIPv6Mreq),
		"GetsockoptInet4Addr":               reflect.ValueOf(syscall.GetsockoptInet4Addr),
		"GetsockoptInt":                     reflect.ValueOf(syscall.GetsockoptInt),
		"Gettimeofday":                      reflect.ValueOf(syscall.Gettimeofday),
		"Getuid":                            reflect.ValueOf(syscall.Getuid),
		"Getwd":                             reflect.ValueOf(syscall.Getwd),
		"HUPCL":                             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"ICANON":                            reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"ICMP6_FILTER":                      reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"ICRNL":                             reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IEXTEN":                            reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFAN_ARRIVAL":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IFAN_DEPARTURE":                    reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFF_ALLMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IFF_ALTPHYS":                       reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFF_CANTCHANGE":                    reflect.ValueOf(constant.MakeFromLiteral("2199410", token.INT, 0)),
		"IFF_CANTCONFIG":                    reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IFF_DEBUG":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFF_DRV_OACTIVE":                   reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFF_DRV_RUNNING":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFF_DYING":                         reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"IFF_LINK0":                         reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"IFF_LINK1":                         reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IFF_LINK2":                         reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IFF_LOOPBACK":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFF_MONITOR":                       reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"IFF_MULTICAST":                     reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IFF_NOARP":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFF_OACTIVE":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IFF_POINTOPOINT":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFF_PPROMISC":                      reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"IFF_PROMISC":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IFF_RENAMING":                      reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"IFF_RUNNING":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFF_SIMPLEX":                       reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IFF_SMART":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFF_STATICARP":                     reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"IFF_UP":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFNAMSIZ":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFT_1822":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IFT_A12MPPSWITCH":                  reflect.ValueOf(constant.MakeFromLiteral("130", token.INT, 0)),
		"IFT_AAL2":                          reflect.ValueOf(constant.MakeFromLiteral("187", token.INT, 0)),
		"IFT_AAL5":                          reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IFT_ADSL":                          reflect.ValueOf(constant.MakeFromLiteral("94", token.INT, 0)),
		"IFT_AFLANE8023":                    reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IFT_AFLANE8025":                    reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IFT_ARAP":                          reflect.ValueOf(constant.MakeFromLiteral("88", token.INT, 0)),
		"IFT_ARCNET":                        reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IFT_ARCNETPLUS":                    reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IFT_ASYNC":                         reflect.ValueOf(constant.MakeFromLiteral("84", token.INT, 0)),
		"IFT_ATM":                           reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IFT_ATMDXI":                        reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"IFT_ATMFUNI":                       reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"IFT_ATMIMA":                        reflect.ValueOf(constant.MakeFromLiteral("107", token.INT, 0)),
		"IFT_ATMLOGICAL":                    reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"IFT_ATMRADIO":                      reflect.ValueOf(constant.MakeFromLiteral("189", token.INT, 0)),
		"IFT_ATMSUBINTERFACE":               reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"IFT_ATMVCIENDPT":                   reflect.ValueOf(constant.MakeFromLiteral("194", token.INT, 0)),
		"IFT_ATMVIRTUAL":                    reflect.ValueOf(constant.MakeFromLiteral("149", token.INT, 0)),
		"IFT_BGPPOLICYACCOUNTING":           reflect.ValueOf(constant.MakeFromLiteral("162", token.INT, 0)),
		"IFT_BRIDGE":                        reflect.ValueOf(constant.MakeFromLiteral("209", token.INT, 0)),
		"IFT_BSC":                           reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"IFT_CARP":                          reflect.ValueOf(constant.MakeFromLiteral("248", token.INT, 0)),
		"IFT_CCTEMUL":                       reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IFT_CEPT":                          reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IFT_CES":                           reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"IFT_CHANNEL":                       reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"IFT_CNR":                           reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"IFT_COFFEE":                        reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"IFT_COMPOSITELINK":                 reflect.ValueOf(constant.MakeFromLiteral("155", token.INT, 0)),
		"IFT_DCN":                           reflect.ValueOf(constant.MakeFromLiteral("141", token.INT, 0)),
		"IFT_DIGITALPOWERLINE":              reflect.ValueOf(constant.MakeFromLiteral("138", token.INT, 0)),
		"IFT_DIGITALWRAPPEROVERHEADCHANNEL": reflect.ValueOf(constant.MakeFromLiteral("186", token.INT, 0)),
		"IFT_DLSW":                          reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IFT_DOCSCABLEDOWNSTREAM":           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IFT_DOCSCABLEMACLAYER":             reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"IFT_DOCSCABLEUPSTREAM":             reflect.ValueOf(constant.MakeFromLiteral("129", token.INT, 0)),
		"IFT_DS0":                           reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"IFT_DS0BUNDLE":                     reflect.ValueOf(constant.MakeFromLiteral("82", token.INT, 0)),
		"IFT_DS1FDL":                        reflect.ValueOf(constant.MakeFromLiteral("170", token.INT, 0)),
		"IFT_DS3":                           reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IFT_DTM":                           reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"IFT_DVBASILN":                      reflect.ValueOf(constant.MakeFromLiteral("172", token.INT, 0)),
		"IFT_DVBASIOUT":                     reflect.ValueOf(constant.MakeFromLiteral("173", token.INT, 0)),
		"IFT_DVBRCCDOWNSTREAM":              reflect.ValueOf(constant.MakeFromLiteral("147", token.INT, 0)),
		"IFT_DVBRCCMACLAYER":                reflect.ValueOf(constant.MakeFromLiteral("146", token.INT, 0)),
		"IFT_DVBRCCUPSTREAM":                reflect.ValueOf(constant.MakeFromLiteral("148", token.INT, 0)),
		"IFT_ENC":                           reflect.ValueOf(constant.MakeFromLiteral("244", token.INT, 0)),
		"IFT_EON":                           reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IFT_EPLRS":                         reflect.ValueOf(constant.MakeFromLiteral("87", token.INT, 0)),
		"IFT_ESCON":                         reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"IFT_ETHER":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IFT_FAITH":                         reflect.ValueOf(constant.MakeFromLiteral("242", token.INT, 0)),
		"IFT_FAST":                          reflect.ValueOf(constant.MakeFromLiteral("125", token.INT, 0)),
		"IFT_FASTETHER":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IFT_FASTETHERFX":                   reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"IFT_FDDI":                          reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IFT_FIBRECHANNEL":                  reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"IFT_FRAMERELAYINTERCONNECT":        reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IFT_FRAMERELAYMPI":                 reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"IFT_FRDLCIENDPT":                   reflect.ValueOf(constant.MakeFromLiteral("193", token.INT, 0)),
		"IFT_FRELAY":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IFT_FRELAYDCE":                     reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IFT_FRF16MFRBUNDLE":                reflect.ValueOf(constant.MakeFromLiteral("163", token.INT, 0)),
		"IFT_FRFORWARD":                     reflect.ValueOf(constant.MakeFromLiteral("158", token.INT, 0)),
		"IFT_G703AT2MB":                     reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"IFT_G703AT64K":                     reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"IFT_GIF":                           reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"IFT_GIGABITETHERNET":               reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"IFT_GR303IDT":                      reflect.ValueOf(constant.MakeFromLiteral("178", token.INT, 0)),
		"IFT_GR303RDT":                      reflect.ValueOf(constant.MakeFromLiteral("177", token.INT, 0)),
		"IFT_H323GATEKEEPER":                reflect.ValueOf(constant.MakeFromLiteral("164", token.INT, 0)),
		"IFT_H323PROXY":                     reflect.ValueOf(constant.MakeFromLiteral("165", token.INT, 0)),
		"IFT_HDH1822":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IFT_HDLC":                          reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"IFT_HDSL2":                         reflect.ValueOf(constant.MakeFromLiteral("168", token.INT, 0)),
		"IFT_HIPERLAN2":                     reflect.ValueOf(constant.MakeFromLiteral("183", token.INT, 0)),
		"IFT_HIPPI":                         reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IFT_HIPPIINTERFACE":                reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IFT_HOSTPAD":                       reflect.ValueOf(constant.MakeFromLiteral("90", token.INT, 0)),
		"IFT_HSSI":                          reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IFT_HY":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IFT_IBM370PARCHAN":                 reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"IFT_IDSL":                          reflect.ValueOf(constant.MakeFromLiteral("154", token.INT, 0)),
		"IFT_IEEE1394":                      reflect.ValueOf(constant.MakeFromLiteral("144", token.INT, 0)),
		"IFT_IEEE80211":                     reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"IFT_IEEE80212":                     reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IFT_IEEE8023ADLAG":                 reflect.ValueOf(constant.MakeFromLiteral("161", token.INT, 0)),
		"IFT_IFGSN":                         reflect.ValueOf(constant.MakeFromLiteral("145", token.INT, 0)),
		"IFT_IMT":                           reflect.ValueOf(constant.MakeFromLiteral("190", token.INT, 0)),
		"IFT_INFINIBAND":                    reflect.ValueOf(constant.MakeFromLiteral("199", token.INT, 0)),
		"IFT_INTERLEAVE":                    reflect.ValueOf(constant.MakeFromLiteral("124", token.INT, 0)),
		"IFT_IP":                            reflect.ValueOf(constant.MakeFromLiteral("126", token.INT, 0)),
		"IFT_IPFORWARD":                     reflect.ValueOf(constant.MakeFromLiteral("142", token.INT, 0)),
		"IFT_IPOVERATM":                     reflect.ValueOf(constant.MakeFromLiteral("114", token.INT, 0)),
		"IFT_IPOVERCDLC":                    reflect.ValueOf(constant.MakeFromLiteral("109", token.INT, 0)),
		"IFT_IPOVERCLAW":                    reflect.ValueOf(constant.MakeFromLiteral("110", token.INT, 0)),
		"IFT_IPSWITCH":                      reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"IFT_IPXIP":                         reflect.ValueOf(constant.MakeFromLiteral("249", token.INT, 0)),
		"IFT_ISDN":                          reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IFT_ISDNBASIC":                     reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IFT_ISDNPRIMARY":                   reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IFT_ISDNS":                         reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"IFT_ISDNU":                         reflect.ValueOf(constant.MakeFromLiteral("76", token.INT, 0)),
		"IFT_ISO88022LLC":                   reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IFT_ISO88023":                      reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IFT_ISO88024":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IFT_ISO88025":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IFT_ISO88025CRFPINT":               reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"IFT_ISO88025DTR":                   reflect.ValueOf(constant.MakeFromLiteral("86", token.INT, 0)),
		"IFT_ISO88025FIBER":                 reflect.ValueOf(constant.MakeFromLiteral("115", token.INT, 0)),
		"IFT_ISO88026":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IFT_ISUP":                          reflect.ValueOf(constant.MakeFromLiteral("179", token.INT, 0)),
		"IFT_L2VLAN":                        reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"IFT_L3IPVLAN":                      reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"IFT_L3IPXVLAN":                     reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"IFT_LAPB":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IFT_LAPD":                          reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"IFT_LAPF":                          reflect.ValueOf(constant.MakeFromLiteral("119", token.INT, 0)),
		"IFT_LOCALTALK":                     reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IFT_LOOP":                          reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IFT_MEDIAMAILOVERIP":               reflect.ValueOf(constant.MakeFromLiteral("139", token.INT, 0)),
		"IFT_MFSIGLINK":                     reflect.ValueOf(constant.MakeFromLiteral("167", token.INT, 0)),
		"IFT_MIOX25":                        reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IFT_MODEM":                         reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IFT_MPC":                           reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"IFT_MPLS":                          reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"IFT_MPLSTUNNEL":                    reflect.ValueOf(constant.MakeFromLiteral("150", token.INT, 0)),
		"IFT_MSDSL":                         reflect.ValueOf(constant.MakeFromLiteral("143", token.INT, 0)),
		"IFT_MVL":                           reflect.ValueOf(constant.MakeFromLiteral("191", token.INT, 0)),
		"IFT_MYRINET":                       reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"IFT_NFAS":                          reflect.ValueOf(constant.MakeFromLiteral("175", token.INT, 0)),
		"IFT_NSIP":                          reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IFT_OPTICALCHANNEL":                reflect.ValueOf(constant.MakeFromLiteral("195", token.INT, 0)),
		"IFT_OPTICALTRANSPORT":              reflect.ValueOf(constant.MakeFromLiteral("196", token.INT, 0)),
		"IFT_OTHER":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IFT_P10":                           reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IFT_P80":                           reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IFT_PARA":                          reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IFT_PFLOG":                         reflect.ValueOf(constant.MakeFromLiteral("246", token.INT, 0)),
		"IFT_PFSYNC":                        reflect.ValueOf(constant.MakeFromLiteral("247", token.INT, 0)),
		"IFT_PLC":                           reflect.ValueOf(constant.MakeFromLiteral("174", token.INT, 0)),
		"IFT_POS":                           reflect.ValueOf(constant.MakeFromLiteral("171", token.INT, 0)),
		"IFT_PPP":                           reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IFT_PPPMULTILINKBUNDLE":            reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"IFT_PROPBWAP2MP":                   reflect.ValueOf(constant.MakeFromLiteral("184", token.INT, 0)),
		"IFT_PROPCNLS":                      reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"IFT_PROPDOCSWIRELESSDOWNSTREAM":    reflect.ValueOf(constant.MakeFromLiteral("181", token.INT, 0)),
		"IFT_PROPDOCSWIRELESSMACLAYER":      reflect.ValueOf(constant.MakeFromLiteral("180", token.INT, 0)),
		"IFT_PROPDOCSWIRELESSUPSTREAM":      reflect.ValueOf(constant.MakeFromLiteral("182", token.INT, 0)),
		"IFT_PROPMUX":                       reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IFT_PROPVIRTUAL":                   reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IFT_PROPWIRELESSP2P":               reflect.ValueOf(constant.MakeFromLiteral("157", token.INT, 0)),
		"IFT_PTPSERIAL":                     reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IFT_PVC":                           reflect.ValueOf(constant.MakeFromLiteral("241", token.INT, 0)),
		"IFT_QLLC":                          reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"IFT_RADIOMAC":                      reflect.ValueOf(constant.MakeFromLiteral("188", token.INT, 0)),
		"IFT_RADSL":                         reflect.ValueOf(constant.MakeFromLiteral("95", token.INT, 0)),
		"IFT_REACHDSL":                      reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"IFT_RFC1483":                       reflect.ValueOf(constant.MakeFromLiteral("159", token.INT, 0)),
		"IFT_RS232":                         reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IFT_RSRB":                          reflect.ValueOf(constant.MakeFromLiteral("79", token.INT, 0)),
		"IFT_SDLC":                          reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IFT_SDSL":                          reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"IFT_SHDSL":                         reflect.ValueOf(constant.MakeFromLiteral("169", token.INT, 0)),
		"IFT_SIP":                           reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IFT_SLIP":                          reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IFT_SMDSDXI":                       reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IFT_SMDSICIP":                      reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IFT_SONET":                         reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IFT_SONETOVERHEADCHANNEL":          reflect.ValueOf(constant.MakeFromLiteral("185", token.INT, 0)),
		"IFT_SONETPATH":                     reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IFT_SONETVT":                       reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IFT_SRP":                           reflect.ValueOf(constant.MakeFromLiteral("151", token.INT, 0)),
		"IFT_SS7SIGLINK":                    reflect.ValueOf(constant.MakeFromLiteral("156", token.INT, 0)),
		"IFT_STACKTOSTACK":                  reflect.ValueOf(constant.MakeFromLiteral("111", token.INT, 0)),
		"IFT_STARLAN":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IFT_STF":                           reflect.ValueOf(constant.MakeFromLiteral("215", token.INT, 0)),
		"IFT_T1":                            reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IFT_TDLC":                          reflect.ValueOf(constant.MakeFromLiteral("116", token.INT, 0)),
		"IFT_TERMPAD":                       reflect.ValueOf(constant.MakeFromLiteral("91", token.INT, 0)),
		"IFT_TR008":                         reflect.ValueOf(constant.MakeFromLiteral("176", token.INT, 0)),
		"IFT_TRANSPHDLC":                    reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"IFT_TUNNEL":                        reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"IFT_ULTRA":                         reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IFT_USB":                           reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"IFT_V11":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IFT_V35":                           reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"IFT_V36":                           reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"IFT_V37":                           reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"IFT_VDSL":                          reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"IFT_VIRTUALIPADDRESS":              reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"IFT_VOICEEM":                       reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"IFT_VOICEENCAP":                    reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"IFT_VOICEFXO":                      reflect.ValueOf(constant.MakeFromLiteral("101", token.INT, 0)),
		"IFT_VOICEFXS":                      reflect.ValueOf(constant.MakeFromLiteral("102", token.INT, 0)),
		"IFT_VOICEOVERATM":                  reflect.ValueOf(constant.MakeFromLiteral("152", token.INT, 0)),
		"IFT_VOICEOVERFRAMERELAY":           reflect.ValueOf(constant.MakeFromLiteral("153", token.INT, 0)),
		"IFT_VOICEOVERIP":                   reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"IFT_X213":                          reflect.ValueOf(constant.MakeFromLiteral("93", token.INT, 0)),
		"IFT_X25":                           reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IFT_X25DDN":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IFT_X25HUNTGROUP":                  reflect.ValueOf(constant.MakeFromLiteral("122", token.INT, 0)),
		"IFT_X25MLP":                        reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"IFT_X25PLE":                        reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IFT_XETHER":                        reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IGNBRK":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IGNCR":                             reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IGNPAR":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IMAXBEL":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"INLCR":                             reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"INPCK":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSA_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("16777215", token.INT, 0)),
		"IN_CLASSA_MAX":                     reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IN_CLASSA_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4278190080", token.INT, 0)),
		"IN_CLASSA_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IN_CLASSB_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IN_CLASSB_MAX":                     reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"IN_CLASSB_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4294901760", token.INT, 0)),
		"IN_CLASSB_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IN_CLASSC_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IN_CLASSC_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4294967040", token.INT, 0)),
		"IN_CLASSC_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IN_CLASSD_HOST":                    reflect.ValueOf(constant.MakeFromLiteral("268435455", token.INT, 0)),
		"IN_CLASSD_NET":                     reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"IN_CLASSD_NSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IN_LOOPBACKNET":                    reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"IN_RFC3021_MASK":                   reflect.ValueOf(constant.MakeFromLiteral("4294967294", token.INT, 0)),
		"IPPROTO_3PC":                       reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IPPROTO_ADFS":                      reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"IPPROTO_AH":                        reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPPROTO_AHIP":                      reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IPPROTO_APES":                      reflect.ValueOf(constant.MakeFromLiteral("99", token.INT, 0)),
		"IPPROTO_ARGUS":                     reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IPPROTO_AX25":                      reflect.ValueOf(constant.MakeFromLiteral("93", token.INT, 0)),
		"IPPROTO_BHA":                       reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IPPROTO_BLT":                       reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IPPROTO_BRSATMON":                  reflect.ValueOf(constant.MakeFromLiteral("76", token.INT, 0)),
		"IPPROTO_CARP":                      reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"IPPROTO_CFTP":                      reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IPPROTO_CHAOS":                     reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IPPROTO_CMTP":                      reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IPPROTO_CPHB":                      reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"IPPROTO_CPNX":                      reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"IPPROTO_DDP":                       reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IPPROTO_DGP":                       reflect.ValueOf(constant.MakeFromLiteral("86", token.INT, 0)),
		"IPPROTO_DIVERT":                    reflect.ValueOf(constant.MakeFromLiteral("258", token.INT, 0)),
		"IPPROTO_DONE":                      reflect.ValueOf(constant.MakeFromLiteral("257", token.INT, 0)),
		"IPPROTO_DSTOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IPPROTO_EGP":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IPPROTO_EMCON":                     reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IPPROTO_ENCAP":                     reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"IPPROTO_EON":                       reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"IPPROTO_ESP":                       reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPPROTO_ETHERIP":                   reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"IPPROTO_FRAGMENT":                  reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPPROTO_GGP":                       reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPPROTO_GMTP":                      reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"IPPROTO_GRE":                       reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IPPROTO_HELLO":                     reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IPPROTO_HMP":                       reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IPPROTO_HOPOPTS":                   reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_ICMP":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPPROTO_ICMPV6":                    reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IPPROTO_IDP":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IPPROTO_IDPR":                      reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IPPROTO_IDRP":                      reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"IPPROTO_IGMP":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPPROTO_IGP":                       reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"IPPROTO_IGRP":                      reflect.ValueOf(constant.MakeFromLiteral("88", token.INT, 0)),
		"IPPROTO_IL":                        reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IPPROTO_INLSP":                     reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IPPROTO_INP":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IPPROTO_IP":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPPROTO_IPCOMP":                    reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"IPPROTO_IPCV":                      reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"IPPROTO_IPEIP":                     reflect.ValueOf(constant.MakeFromLiteral("94", token.INT, 0)),
		"IPPROTO_IPIP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_IPPC":                      reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"IPPROTO_IPV4":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPPROTO_IPV6":                      reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IPPROTO_IRTP":                      reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IPPROTO_KRYPTOLAN":                 reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"IPPROTO_LARP":                      reflect.ValueOf(constant.MakeFromLiteral("91", token.INT, 0)),
		"IPPROTO_LEAF1":                     reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"IPPROTO_LEAF2":                     reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IPPROTO_MAX":                       reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"IPPROTO_MAXID":                     reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IPPROTO_MEAS":                      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IPPROTO_MH":                        reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"IPPROTO_MHRP":                      reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IPPROTO_MICP":                      reflect.ValueOf(constant.MakeFromLiteral("95", token.INT, 0)),
		"IPPROTO_MOBILE":                    reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IPPROTO_MPLS":                      reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"IPPROTO_MTP":                       reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"IPPROTO_MUX":                       reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IPPROTO_ND":                        reflect.ValueOf(constant.MakeFromLiteral("77", token.INT, 0)),
		"IPPROTO_NHRP":                      reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IPPROTO_NONE":                      reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPPROTO_NSP":                       reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IPPROTO_NVPII":                     reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IPPROTO_OLD_DIVERT":                reflect.ValueOf(constant.MakeFromLiteral("254", token.INT, 0)),
		"IPPROTO_OSPFIGP":                   reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"IPPROTO_PFSYNC":                    reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"IPPROTO_PGM":                       reflect.ValueOf(constant.MakeFromLiteral("113", token.INT, 0)),
		"IPPROTO_PIGP":                      reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPPROTO_PIM":                       reflect.ValueOf(constant.MakeFromLiteral("103", token.INT, 0)),
		"IPPROTO_PRM":                       reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IPPROTO_PUP":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPPROTO_PVP":                       reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"IPPROTO_RAW":                       reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IPPROTO_RCCMON":                    reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPPROTO_RDP":                       reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IPPROTO_ROUTING":                   reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPPROTO_RSVP":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPPROTO_RVD":                       reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"IPPROTO_SATEXPAK":                  reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IPPROTO_SATMON":                    reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"IPPROTO_SCCSP":                     reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"IPPROTO_SCTP":                      reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"IPPROTO_SDRP":                      reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IPPROTO_SEND":                      reflect.ValueOf(constant.MakeFromLiteral("259", token.INT, 0)),
		"IPPROTO_SEP":                       reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IPPROTO_SKIP":                      reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IPPROTO_SPACER":                    reflect.ValueOf(constant.MakeFromLiteral("32767", token.INT, 0)),
		"IPPROTO_SRPC":                      reflect.ValueOf(constant.MakeFromLiteral("90", token.INT, 0)),
		"IPPROTO_ST":                        reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IPPROTO_SVMTP":                     reflect.ValueOf(constant.MakeFromLiteral("82", token.INT, 0)),
		"IPPROTO_SWIPE":                     reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IPPROTO_TCF":                       reflect.ValueOf(constant.MakeFromLiteral("87", token.INT, 0)),
		"IPPROTO_TCP":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IPPROTO_TLSP":                      reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"IPPROTO_TP":                        reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPPROTO_TPXX":                      reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IPPROTO_TRUNK1":                    reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IPPROTO_TRUNK2":                    reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IPPROTO_TTP":                       reflect.ValueOf(constant.MakeFromLiteral("84", token.INT, 0)),
		"IPPROTO_UDP":                       reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IPPROTO_VINES":                     reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"IPPROTO_VISA":                      reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"IPPROTO_VMTP":                      reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"IPPROTO_WBEXPAK":                   reflect.ValueOf(constant.MakeFromLiteral("79", token.INT, 0)),
		"IPPROTO_WBMON":                     reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"IPPROTO_WSN":                       reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IPPROTO_XNET":                      reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IPPROTO_XTP":                       reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IPV6_AUTOFLOWLABEL":                reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IPV6_BINDANY":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IPV6_BINDV6ONLY":                   reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IPV6_CHECKSUM":                     reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"IPV6_DEFAULT_MULTICAST_HOPS":       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_DEFAULT_MULTICAST_LOOP":       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_DEFHLIM":                      reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IPV6_DONTFRAG":                     reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IPV6_DSTOPTS":                      reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IPV6_FAITH":                        reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"IPV6_FLOWINFO_MASK":                reflect.ValueOf(constant.MakeFromLiteral("4294967055", token.INT, 0)),
		"IPV6_FLOWLABEL_MASK":               reflect.ValueOf(constant.MakeFromLiteral("4294905600", token.INT, 0)),
		"IPV6_FRAGTTL":                      reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"IPV6_FW_ADD":                       reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"IPV6_FW_DEL":                       reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IPV6_FW_FLUSH":                     reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IPV6_FW_GET":                       reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"IPV6_FW_ZERO":                      reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"IPV6_HLIMDEC":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_HOPLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"IPV6_HOPOPTS":                      reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IPV6_IPSEC_POLICY":                 reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"IPV6_JOIN_GROUP":                   reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IPV6_LEAVE_GROUP":                  reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IPV6_MAXHLIM":                      reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"IPV6_MAXOPTHDR":                    reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IPV6_MAXPACKET":                    reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IPV6_MAX_GROUP_SRC_FILTER":         reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IPV6_MAX_MEMBERSHIPS":              reflect.ValueOf(constant.MakeFromLiteral("4095", token.INT, 0)),
		"IPV6_MAX_SOCK_SRC_FILTER":          reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IPV6_MIN_MEMBERSHIPS":              reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IPV6_MMTU":                         reflect.ValueOf(constant.MakeFromLiteral("1280", token.INT, 0)),
		"IPV6_MSFILTER":                     reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IPV6_MULTICAST_HOPS":               reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IPV6_MULTICAST_IF":                 reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IPV6_MULTICAST_LOOP":               reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IPV6_NEXTHOP":                      reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IPV6_PATHMTU":                      reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IPV6_PKTINFO":                      reflect.ValueOf(constant.MakeFromLiteral("46", token.INT, 0)),
		"IPV6_PORTRANGE":                    reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IPV6_PORTRANGE_DEFAULT":            reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_PORTRANGE_HIGH":               reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_PORTRANGE_LOW":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IPV6_PREFER_TEMPADDR":              reflect.ValueOf(constant.MakeFromLiteral("63", token.INT, 0)),
		"IPV6_RECVDSTOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IPV6_RECVHOPLIMIT":                 reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"IPV6_RECVHOPOPTS":                  reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"IPV6_RECVPATHMTU":                  reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IPV6_RECVPKTINFO":                  reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"IPV6_RECVRTHDR":                    reflect.ValueOf(constant.MakeFromLiteral("38", token.INT, 0)),
		"IPV6_RECVTCLASS":                   reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IPV6_RTHDR":                        reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IPV6_RTHDRDSTOPTS":                 reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"IPV6_RTHDR_LOOSE":                  reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_RTHDR_STRICT":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IPV6_RTHDR_TYPE_0":                 reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IPV6_SOCKOPT_RESERVED1":            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IPV6_TCLASS":                       reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IPV6_UNICAST_HOPS":                 reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IPV6_USE_MIN_MTU":                  reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IPV6_V6ONLY":                       reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"IPV6_VERSION":                      reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"IPV6_VERSION_MASK":                 reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"IP_ADD_MEMBERSHIP":                 reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"IP_ADD_SOURCE_MEMBERSHIP":          reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"IP_BINDANY":                        reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"IP_BLOCK_SOURCE":                   reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_LOOP":         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DEFAULT_MULTICAST_TTL":          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_DF":                             reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"IP_DONTFRAG":                       reflect.ValueOf(constant.MakeFromLiteral("67", token.INT, 0)),
		"IP_DROP_MEMBERSHIP":                reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"IP_DROP_SOURCE_MEMBERSHIP":         reflect.ValueOf(constant.MakeFromLiteral("71", token.INT, 0)),
		"IP_DUMMYNET3":                      reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"IP_DUMMYNET_CONFIGURE":             reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"IP_DUMMYNET_DEL":                   reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"IP_DUMMYNET_FLUSH":                 reflect.ValueOf(constant.MakeFromLiteral("62", token.INT, 0)),
		"IP_DUMMYNET_GET":                   reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"IP_FAITH":                          reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"IP_FW3":                            reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"IP_FW_ADD":                         reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"IP_FW_DEL":                         reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"IP_FW_FLUSH":                       reflect.ValueOf(constant.MakeFromLiteral("52", token.INT, 0)),
		"IP_FW_GET":                         reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"IP_FW_NAT_CFG":                     reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"IP_FW_NAT_DEL":                     reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"IP_FW_NAT_GET_CONFIG":              reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"IP_FW_NAT_GET_LOG":                 reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"IP_FW_RESETLOG":                    reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"IP_FW_TABLE_ADD":                   reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"IP_FW_TABLE_DEL":                   reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"IP_FW_TABLE_FLUSH":                 reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"IP_FW_TABLE_GETSIZE":               reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"IP_FW_TABLE_LIST":                  reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"IP_FW_ZERO":                        reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"IP_HDRINCL":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_IPSEC_POLICY":                   reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"IP_MAXPACKET":                      reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"IP_MAX_GROUP_SRC_FILTER":           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"IP_MAX_MEMBERSHIPS":                reflect.ValueOf(constant.MakeFromLiteral("4095", token.INT, 0)),
		"IP_MAX_SOCK_MUTE_FILTER":           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IP_MAX_SOCK_SRC_FILTER":            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"IP_MAX_SOURCE_FILTER":              reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IP_MF":                             reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"IP_MINTTL":                         reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"IP_MIN_MEMBERSHIPS":                reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"IP_MSFILTER":                       reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"IP_MSS":                            reflect.ValueOf(constant.MakeFromLiteral("576", token.INT, 0)),
		"IP_MULTICAST_IF":                   reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"IP_MULTICAST_LOOP":                 reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"IP_MULTICAST_TTL":                  reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"IP_MULTICAST_VIF":                  reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"IP_OFFMASK":                        reflect.ValueOf(constant.MakeFromLiteral("8191", token.INT, 0)),
		"IP_ONESBCAST":                      reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"IP_OPTIONS":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_PORTRANGE":                      reflect.ValueOf(constant.MakeFromLiteral("19", token.INT, 0)),
		"IP_PORTRANGE_DEFAULT":              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"IP_PORTRANGE_HIGH":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"IP_PORTRANGE_LOW":                  reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"IP_RECVDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IP_RECVIF":                         reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"IP_RECVOPTS":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"IP_RECVRETOPTS":                    reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"IP_RECVTOS":                        reflect.ValueOf(constant.MakeFromLiteral("68", token.INT, 0)),
		"IP_RECVTTL":                        reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"IP_RETOPTS":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"IP_RF":                             reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"IP_RSVP_OFF":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"IP_RSVP_ON":                        reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"IP_RSVP_VIF_OFF":                   reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"IP_RSVP_VIF_ON":                    reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"IP_SENDSRCADDR":                    reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"IP_TOS":                            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"IP_TTL":                            reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"IP_UNBLOCK_SOURCE":                 reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"ISIG":                              reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"ISTRIP":                            reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"IXANY":                             reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"IXOFF":                             reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"IXON":                              reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"ImplementsGetwd":                   reflect.ValueOf(syscall.ImplementsGetwd),
		"Issetugid":                         reflect.ValueOf(syscall.Issetugid),
		"Kevent":                            reflect.ValueOf(syscall.Kevent),
		"Kqueue":                            reflect.ValueOf(syscall.Kqueue),
		"LOCK_EX":                           reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"LOCK_NB":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"LOCK_SH":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"LOCK_UN":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"Lchown":                            reflect.ValueOf(syscall.Lchown),
		"Link":                              reflect.ValueOf(syscall.Link),
		"Listen":                            reflect.ValueOf(syscall.Listen),
		"Lstat":                             reflect.ValueOf(syscall.Lstat),
		"MADV_AUTOSYNC":                     reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"MADV_CORE":                         reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"MADV_DONTNEED":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MADV_FREE":                         reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"MADV_NOCORE":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MADV_NORMAL":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MADV_NOSYNC":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"MADV_PROTECT":                      reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"MADV_RANDOM":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MADV_SEQUENTIAL":                   reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MADV_WILLNEED":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"MAP_32BIT":                         reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"MAP_ALIGNED_SUPER":                 reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"MAP_ALIGNMENT_MASK":                reflect.ValueOf(constant.MakeFromLiteral("-16777216", token.INT, 0)),
		"MAP_ALIGNMENT_SHIFT":               reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"MAP_ANON":                          reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"MAP_ANONYMOUS":                     reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"MAP_COPY":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_FILE":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"MAP_FIXED":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MAP_HASSEMAPHORE":                  reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"MAP_NOCORE":                        reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"MAP_NORESERVE":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MAP_NOSYNC":                        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"MAP_PREFAULT_READ":                 reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"MAP_PRIVATE":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MAP_RENAME":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MAP_RESERVED0080":                  reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MAP_RESERVED0100":                  reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MAP_SHARED":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MAP_STACK":                         reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"MCL_CURRENT":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MCL_FUTURE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_CMSG_CLOEXEC":                  reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"MSG_COMPAT":                        reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"MSG_CTRUNC":                        reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"MSG_DONTROUTE":                     reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"MSG_DONTWAIT":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"MSG_EOF":                           reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"MSG_EOR":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"MSG_NBIO":                          reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"MSG_NOSIGNAL":                      reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"MSG_NOTIFICATION":                  reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"MSG_OOB":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MSG_PEEK":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MSG_TRUNC":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"MSG_WAITALL":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"MS_ASYNC":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"MS_INVALIDATE":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"MS_SYNC":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"Mkdir":                             reflect.ValueOf(syscall.Mkdir),
		"Mkfifo":                            reflect.ValueOf(syscall.Mkfifo),
		"Mknod":                             reflect.ValueOf(syscall.Mknod),
		"Mmap":                              reflect.ValueOf(syscall.Mmap),
		"Munmap":                            reflect.ValueOf(syscall.Munmap),
		"NAME_MAX":                          reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"NET_RT_DUMP":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NET_RT_FLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NET_RT_IFLIST":                     reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"NET_RT_IFLISTL":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"NET_RT_IFMALIST":                   reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NET_RT_MAXID":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"NOFLSH":                            reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"NOTE_ATTRIB":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"NOTE_CHILD":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NOTE_DELETE":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NOTE_EXEC":                         reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"NOTE_EXIT":                         reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"NOTE_EXTEND":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"NOTE_FFAND":                        reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"NOTE_FFCOPY":                       reflect.ValueOf(constant.MakeFromLiteral("3221225472", token.INT, 0)),
		"NOTE_FFCTRLMASK":                   reflect.ValueOf(constant.MakeFromLiteral("3221225472", token.INT, 0)),
		"NOTE_FFLAGSMASK":                   reflect.ValueOf(constant.MakeFromLiteral("16777215", token.INT, 0)),
		"NOTE_FFNOP":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"NOTE_FFOR":                         reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"NOTE_FORK":                         reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"NOTE_LINK":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"NOTE_LOWAT":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NOTE_PCTRLMASK":                    reflect.ValueOf(constant.MakeFromLiteral("4026531840", token.INT, 0)),
		"NOTE_PDATAMASK":                    reflect.ValueOf(constant.MakeFromLiteral("1048575", token.INT, 0)),
		"NOTE_RENAME":                       reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"NOTE_REVOKE":                       reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"NOTE_TRACK":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"NOTE_TRACKERR":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"NOTE_TRIGGER":                      reflect.ValueOf(constant.MakeFromLiteral("16777216", token.INT, 0)),
		"NOTE_WRITE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Nanosleep":                         reflect.ValueOf(syscall.Nanosleep),
		"NsecToTimespec":                    reflect.ValueOf(syscall.NsecToTimespec),
		"NsecToTimeval":                     reflect.ValueOf(syscall.NsecToTimeval),
		"OCRNL":                             reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"ONLCR":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"ONLRET":                            reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"ONOCR":                             reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"ONOEOT":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"OPOST":                             reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"O_ACCMODE":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"O_APPEND":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"O_ASYNC":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"O_CLOEXEC":                         reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"O_CREAT":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"O_DIRECT":                          reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"O_DIRECTORY":                       reflect.ValueOf(constant.MakeFromLiteral("131072", token.INT, 0)),
		"O_EXCL":                            reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"O_EXEC":                            reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"O_EXLOCK":                          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"O_FSYNC":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_NDELAY":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"O_NOCTTY":                          reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"O_NOFOLLOW":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"O_NONBLOCK":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"O_RDONLY":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"O_RDWR":                            reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"O_SHLOCK":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"O_SYNC":                            reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"O_TRUNC":                           reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"O_TTY_INIT":                        reflect.ValueOf(constant.MakeFromLiteral("524288", token.INT, 0)),
		"O_WRONLY":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Open":                              reflect.ValueOf(syscall.Open),
		"PARENB":                            reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"PARMRK":                            reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PARODD":                            reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"PENDIN":                            reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"PRIO_PGRP":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PRIO_PROCESS":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PRIO_USER":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PROT_EXEC":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"PROT_NONE":                         reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"PROT_READ":                         reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"PROT_WRITE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"PTRACE_CONT":                       reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"PTRACE_KILL":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"PTRACE_TRACEME":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"ParseDirent":                       reflect.ValueOf(syscall.ParseDirent),
		"ParseRoutingMessage":               reflect.ValueOf(syscall.ParseRoutingMessage),
		"ParseRoutingSockaddr":              reflect.ValueOf(syscall.ParseRoutingSockaddr),
		"ParseSocketControlMessage":         reflect.ValueOf(syscall.ParseSocketControlMessage),
		"ParseUnixRights":                   reflect.ValueOf(syscall.ParseUnixRights),
		"Pathconf":                          reflect.ValueOf(syscall.Pathconf),
		"Pipe":                              reflect.ValueOf(syscall.Pipe),
		"Pipe2":                             reflect.ValueOf(syscall.Pipe2),
		"Pread":                             reflect.ValueOf(syscall.Pread),
		"Pwrite":                            reflect.ValueOf(syscall.Pwrite),
		"RLIMIT_AS":                         reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RLIMIT_CORE":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RLIMIT_CPU":                        reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RLIMIT_DATA":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RLIMIT_FSIZE":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RLIMIT_NOFILE":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RLIMIT_STACK":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RLIM_INFINITY":                     reflect.ValueOf(constant.MakeFromLiteral("9223372036854775807", token.INT, 0)),
		"RTAX_AUTHOR":                       reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTAX_BRD":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTAX_DST":                          reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RTAX_GATEWAY":                      reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTAX_GENMASK":                      reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTAX_IFA":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTAX_IFP":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTAX_MAX":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTAX_NETMASK":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTA_AUTHOR":                        reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTA_BRD":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTA_DST":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTA_GATEWAY":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTA_GENMASK":                       reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTA_IFA":                           reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTA_IFP":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTA_NETMASK":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTF_BLACKHOLE":                     reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"RTF_BROADCAST":                     reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"RTF_DONE":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTF_DYNAMIC":                       reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTF_FMASK":                         reflect.ValueOf(constant.MakeFromLiteral("268752904", token.INT, 0)),
		"RTF_GATEWAY":                       reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTF_GWFLAG_COMPAT":                 reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"RTF_HOST":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTF_LLDATA":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTF_LLINFO":                        reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"RTF_LOCAL":                         reflect.ValueOf(constant.MakeFromLiteral("2097152", token.INT, 0)),
		"RTF_MODIFIED":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTF_MULTICAST":                     reflect.ValueOf(constant.MakeFromLiteral("8388608", token.INT, 0)),
		"RTF_PINNED":                        reflect.ValueOf(constant.MakeFromLiteral("1048576", token.INT, 0)),
		"RTF_PRCLONING":                     reflect.ValueOf(constant.MakeFromLiteral("65536", token.INT, 0)),
		"RTF_PROTO1":                        reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"RTF_PROTO2":                        reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"RTF_PROTO3":                        reflect.ValueOf(constant.MakeFromLiteral("262144", token.INT, 0)),
		"RTF_REJECT":                        reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTF_RNH_LOCKED":                    reflect.ValueOf(constant.MakeFromLiteral("1073741824", token.INT, 0)),
		"RTF_STATIC":                        reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"RTF_STICKY":                        reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"RTF_UP":                            reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTF_XRESOLVE":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"RTM_ADD":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTM_CHANGE":                        reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"RTM_DELADDR":                       reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"RTM_DELETE":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTM_DELMADDR":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTM_GET":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTM_IEEE80211":                     reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"RTM_IFANNOUNCE":                    reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"RTM_IFINFO":                        reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"RTM_LOCK":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTM_LOSING":                        reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTM_MISS":                          reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"RTM_NEWADDR":                       reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"RTM_NEWMADDR":                      reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"RTM_OLDADD":                        reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"RTM_OLDDEL":                        reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"RTM_REDIRECT":                      reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"RTM_RESOLVE":                       reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"RTM_RTTUNIT":                       reflect.ValueOf(constant.MakeFromLiteral("1000000", token.INT, 0)),
		"RTM_VERSION":                       reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"RTV_EXPIRE":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"RTV_HOPCOUNT":                      reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RTV_MTU":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RTV_RPIPE":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"RTV_RTT":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"RTV_RTTVAR":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"RTV_SPIPE":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"RTV_SSTHRESH":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"RTV_WEIGHT":                        reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"RT_CACHING_CONTEXT":                reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"RT_DEFAULT_FIB":                    reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RT_NORTREF":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"RUSAGE_CHILDREN":                   reflect.ValueOf(constant.MakeFromLiteral("-1", token.INT, 0)),
		"RUSAGE_SELF":                       reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"RUSAGE_THREAD":                     reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"Read":                              reflect.ValueOf(syscall.Read),
		"ReadDirent":                        reflect.ValueOf(syscall.ReadDirent),
		"Readlink":                          reflect.ValueOf(syscall.Readlink),
		"Recvfrom":                          reflect.ValueOf(syscall.Recvfrom),
		"Recvmsg":                           reflect.ValueOf(syscall.Recvmsg),
		"Rename":                            reflect.ValueOf(syscall.Rename),
		"Revoke":                            reflect.ValueOf(syscall.Revoke),
		"Rmdir":                             reflect.ValueOf(syscall.Rmdir),
		"RouteRIB":                          reflect.ValueOf(syscall.RouteRIB),
		"SCM_BINTIME":                       reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SCM_CREDS":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SCM_RIGHTS":                        reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SCM_TIMESTAMP":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SHUT_RD":                           reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"SHUT_RDWR":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SHUT_WR":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SIGABRT":                           reflect.ValueOf(syscall.SIGABRT),
		"SIGALRM":                           reflect.ValueOf(syscall.SIGALRM),
		"SIGBUS":                            reflect.ValueOf(syscall.SIGBUS),
		"SIGCHLD":                           reflect.ValueOf(syscall.SIGCHLD),
		"SIGCONT":                           reflect.ValueOf(syscall.SIGCONT),
		"SIGEMT":                            reflect.ValueOf(syscall.SIGEMT),
		"SIGFPE":                            reflect.ValueOf(syscall.SIGFPE),
		"SIGHUP":                            reflect.ValueOf(syscall.SIGHUP),
		"SIGILL":                            reflect.ValueOf(syscall.SIGILL),
		"SIGINFO":                           reflect.ValueOf(syscall.SIGINFO),
		"SIGINT":                            reflect.ValueOf(syscall.SIGINT),
		"SIGIO":                             reflect.ValueOf(syscall.SIGIO),
		"SIGIOT":                            reflect.ValueOf(syscall.SIGIOT),
		"SIGKILL":                           reflect.ValueOf(syscall.SIGKILL),
		"SIGLIBRT":                          reflect.ValueOf(syscall.SIGLIBRT),
		"SIGLWP":                            reflect.ValueOf(syscall.SIGLWP),
		"SIGPIPE":                           reflect.ValueOf(syscall.SIGPIPE),
		"SIGPROF":                           reflect.ValueOf(syscall.SIGPROF),
		"SIGQUIT":                           reflect.ValueOf(syscall.SIGQUIT),
		"SIGSEGV":                           reflect.ValueOf(syscall.SIGSEGV),
		"SIGSTOP":                           reflect.ValueOf(syscall.SIGSTOP),
		"SIGSYS":                            reflect.ValueOf(syscall.SIGSYS),
		"SIGTERM":                           reflect.ValueOf(syscall.SIGTERM),
		"SIGTHR":                            reflect.ValueOf(syscall.SIGTHR),
		"SIGTRAP":                           reflect.ValueOf(syscall.SIGTRAP),
		"SIGTSTP":                           reflect.ValueOf(syscall.SIGTSTP),
		"SIGTTIN":                           reflect.ValueOf(syscall.SIGTTIN),
		"SIGTTOU":                           reflect.ValueOf(syscall.SIGTTOU),
		"SIGURG":                            reflect.ValueOf(syscall.SIGURG),
		"SIGUSR1":                           reflect.ValueOf(syscall.SIGUSR1),
		"SIGUSR2":                           reflect.ValueOf(syscall.SIGUSR2),
		"SIGVTALRM":                         reflect.ValueOf(syscall.SIGVTALRM),
		"SIGWINCH":                          reflect.ValueOf(syscall.SIGWINCH),
		"SIGXCPU":                           reflect.ValueOf(syscall.SIGXCPU),
		"SIGXFSZ":                           reflect.ValueOf(syscall.SIGXFSZ),
		"SIOCADDMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("2149607729", token.INT, 0)),
		"SIOCADDRT":                         reflect.ValueOf(constant.MakeFromLiteral("2151707146", token.INT, 0)),
		"SIOCAIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("2151704858", token.INT, 0)),
		"SIOCAIFGROUP":                      reflect.ValueOf(constant.MakeFromLiteral("2150132103", token.INT, 0)),
		"SIOCALIFADDR":                      reflect.ValueOf(constant.MakeFromLiteral("2165860635", token.INT, 0)),
		"SIOCATMARK":                        reflect.ValueOf(constant.MakeFromLiteral("1074033415", token.INT, 0)),
		"SIOCDELMULTI":                      reflect.ValueOf(constant.MakeFromLiteral("2149607730", token.INT, 0)),
		"SIOCDELRT":                         reflect.ValueOf(constant.MakeFromLiteral("2151707147", token.INT, 0)),
		"SIOCDIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("2149607705", token.INT, 0)),
		"SIOCDIFGROUP":                      reflect.ValueOf(constant.MakeFromLiteral("2150132105", token.INT, 0)),
		"SIOCDIFPHYADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2149607753", token.INT, 0)),
		"SIOCDLIFADDR":                      reflect.ValueOf(constant.MakeFromLiteral("2165860637", token.INT, 0)),
		"SIOCGDRVSPEC":                      reflect.ValueOf(constant.MakeFromLiteral("3223873915", token.INT, 0)),
		"SIOCGETSGCNT":                      reflect.ValueOf(constant.MakeFromLiteral("3223351824", token.INT, 0)),
		"SIOCGETVIFCNT":                     reflect.ValueOf(constant.MakeFromLiteral("3223876111", token.INT, 0)),
		"SIOCGHIWAT":                        reflect.ValueOf(constant.MakeFromLiteral("1074033409", token.INT, 0)),
		"SIOCGIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("3223349537", token.INT, 0)),
		"SIOCGIFBRDADDR":                    reflect.ValueOf(constant.MakeFromLiteral("3223349539", token.INT, 0)),
		"SIOCGIFCAP":                        reflect.ValueOf(constant.MakeFromLiteral("3223349535", token.INT, 0)),
		"SIOCGIFCONF":                       reflect.ValueOf(constant.MakeFromLiteral("3222300964", token.INT, 0)),
		"SIOCGIFDESCR":                      reflect.ValueOf(constant.MakeFromLiteral("3223349546", token.INT, 0)),
		"SIOCGIFDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("3223349538", token.INT, 0)),
		"SIOCGIFFIB":                        reflect.ValueOf(constant.MakeFromLiteral("3223349596", token.INT, 0)),
		"SIOCGIFFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("3223349521", token.INT, 0)),
		"SIOCGIFGENERIC":                    reflect.ValueOf(constant.MakeFromLiteral("3223349562", token.INT, 0)),
		"SIOCGIFGMEMB":                      reflect.ValueOf(constant.MakeFromLiteral("3223873930", token.INT, 0)),
		"SIOCGIFGROUP":                      reflect.ValueOf(constant.MakeFromLiteral("3223873928", token.INT, 0)),
		"SIOCGIFINDEX":                      reflect.ValueOf(constant.MakeFromLiteral("3223349536", token.INT, 0)),
		"SIOCGIFMAC":                        reflect.ValueOf(constant.MakeFromLiteral("3223349542", token.INT, 0)),
		"SIOCGIFMEDIA":                      reflect.ValueOf(constant.MakeFromLiteral("3224398136", token.INT, 0)),
		"SIOCGIFMETRIC":                     reflect.ValueOf(constant.MakeFromLiteral("3223349527", token.INT, 0)),
		"SIOCGIFMTU":                        reflect.ValueOf(constant.MakeFromLiteral("3223349555", token.INT, 0)),
		"SIOCGIFNETMASK":                    reflect.ValueOf(constant.MakeFromLiteral("3223349541", token.INT, 0)),
		"SIOCGIFPDSTADDR":                   reflect.ValueOf(constant.MakeFromLiteral("3223349576", token.INT, 0)),
		"SIOCGIFPHYS":                       reflect.ValueOf(constant.MakeFromLiteral("3223349557", token.INT, 0)),
		"SIOCGIFPSRCADDR":                   reflect.ValueOf(constant.MakeFromLiteral("3223349575", token.INT, 0)),
		"SIOCGIFSTATUS":                     reflect.ValueOf(constant.MakeFromLiteral("3274795323", token.INT, 0)),
		"SIOCGLIFADDR":                      reflect.ValueOf(constant.MakeFromLiteral("3239602460", token.INT, 0)),
		"SIOCGLIFPHYADDR":                   reflect.ValueOf(constant.MakeFromLiteral("3239602507", token.INT, 0)),
		"SIOCGLOWAT":                        reflect.ValueOf(constant.MakeFromLiteral("1074033411", token.INT, 0)),
		"SIOCGPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("1074033417", token.INT, 0)),
		"SIOCGPRIVATE_0":                    reflect.ValueOf(constant.MakeFromLiteral("3223349584", token.INT, 0)),
		"SIOCGPRIVATE_1":                    reflect.ValueOf(constant.MakeFromLiteral("3223349585", token.INT, 0)),
		"SIOCIFCREATE":                      reflect.ValueOf(constant.MakeFromLiteral("3223349626", token.INT, 0)),
		"SIOCIFCREATE2":                     reflect.ValueOf(constant.MakeFromLiteral("3223349628", token.INT, 0)),
		"SIOCIFDESTROY":                     reflect.ValueOf(constant.MakeFromLiteral("2149607801", token.INT, 0)),
		"SIOCIFGCLONERS":                    reflect.ValueOf(constant.MakeFromLiteral("3222301048", token.INT, 0)),
		"SIOCSDRVSPEC":                      reflect.ValueOf(constant.MakeFromLiteral("2150132091", token.INT, 0)),
		"SIOCSHIWAT":                        reflect.ValueOf(constant.MakeFromLiteral("2147775232", token.INT, 0)),
		"SIOCSIFADDR":                       reflect.ValueOf(constant.MakeFromLiteral("2149607692", token.INT, 0)),
		"SIOCSIFBRDADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2149607699", token.INT, 0)),
		"SIOCSIFCAP":                        reflect.ValueOf(constant.MakeFromLiteral("2149607710", token.INT, 0)),
		"SIOCSIFDESCR":                      reflect.ValueOf(constant.MakeFromLiteral("2149607721", token.INT, 0)),
		"SIOCSIFDSTADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2149607694", token.INT, 0)),
		"SIOCSIFFIB":                        reflect.ValueOf(constant.MakeFromLiteral("2149607773", token.INT, 0)),
		"SIOCSIFFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("2149607696", token.INT, 0)),
		"SIOCSIFGENERIC":                    reflect.ValueOf(constant.MakeFromLiteral("2149607737", token.INT, 0)),
		"SIOCSIFLLADDR":                     reflect.ValueOf(constant.MakeFromLiteral("2149607740", token.INT, 0)),
		"SIOCSIFMAC":                        reflect.ValueOf(constant.MakeFromLiteral("2149607719", token.INT, 0)),
		"SIOCSIFMEDIA":                      reflect.ValueOf(constant.MakeFromLiteral("3223349559", token.INT, 0)),
		"SIOCSIFMETRIC":                     reflect.ValueOf(constant.MakeFromLiteral("2149607704", token.INT, 0)),
		"SIOCSIFMTU":                        reflect.ValueOf(constant.MakeFromLiteral("2149607732", token.INT, 0)),
		"SIOCSIFNAME":                       reflect.ValueOf(constant.MakeFromLiteral("2149607720", token.INT, 0)),
		"SIOCSIFNETMASK":                    reflect.ValueOf(constant.MakeFromLiteral("2149607702", token.INT, 0)),
		"SIOCSIFPHYADDR":                    reflect.ValueOf(constant.MakeFromLiteral("2151704902", token.INT, 0)),
		"SIOCSIFPHYS":                       reflect.ValueOf(constant.MakeFromLiteral("2149607734", token.INT, 0)),
		"SIOCSIFRVNET":                      reflect.ValueOf(constant.MakeFromLiteral("3223349595", token.INT, 0)),
		"SIOCSIFVNET":                       reflect.ValueOf(constant.MakeFromLiteral("3223349594", token.INT, 0)),
		"SIOCSLIFPHYADDR":                   reflect.ValueOf(constant.MakeFromLiteral("2165860682", token.INT, 0)),
		"SIOCSLOWAT":                        reflect.ValueOf(constant.MakeFromLiteral("2147775234", token.INT, 0)),
		"SIOCSPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("2147775240", token.INT, 0)),
		"SOCK_CLOEXEC":                      reflect.ValueOf(constant.MakeFromLiteral("268435456", token.INT, 0)),
		"SOCK_DGRAM":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SOCK_MAXADDRLEN":                   reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"SOCK_NONBLOCK":                     reflect.ValueOf(constant.MakeFromLiteral("536870912", token.INT, 0)),
		"SOCK_RAW":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SOCK_RDM":                          reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SOCK_SEQPACKET":                    reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SOCK_STREAM":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SOL_SOCKET":                        reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"SOMAXCONN":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_ACCEPTCONN":                     reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SO_ACCEPTFILTER":                   reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"SO_BINTIME":                        reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"SO_BROADCAST":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SO_DEBUG":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SO_DONTROUTE":                      reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SO_ERROR":                          reflect.ValueOf(constant.MakeFromLiteral("4103", token.INT, 0)),
		"SO_KEEPALIVE":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SO_LABEL":                          reflect.ValueOf(constant.MakeFromLiteral("4105", token.INT, 0)),
		"SO_LINGER":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SO_LISTENINCQLEN":                  reflect.ValueOf(constant.MakeFromLiteral("4115", token.INT, 0)),
		"SO_LISTENQLEN":                     reflect.ValueOf(constant.MakeFromLiteral("4114", token.INT, 0)),
		"SO_LISTENQLIMIT":                   reflect.ValueOf(constant.MakeFromLiteral("4113", token.INT, 0)),
		"SO_NOSIGPIPE":                      reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"SO_NO_DDP":                         reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"SO_NO_OFFLOAD":                     reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"SO_OOBINLINE":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"SO_PEERLABEL":                      reflect.ValueOf(constant.MakeFromLiteral("4112", token.INT, 0)),
		"SO_PROTOCOL":                       reflect.ValueOf(constant.MakeFromLiteral("4118", token.INT, 0)),
		"SO_PROTOTYPE":                      reflect.ValueOf(constant.MakeFromLiteral("4118", token.INT, 0)),
		"SO_RCVBUF":                         reflect.ValueOf(constant.MakeFromLiteral("4098", token.INT, 0)),
		"SO_RCVLOWAT":                       reflect.ValueOf(constant.MakeFromLiteral("4100", token.INT, 0)),
		"SO_RCVTIMEO":                       reflect.ValueOf(constant.MakeFromLiteral("4102", token.INT, 0)),
		"SO_REUSEADDR":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SO_REUSEPORT":                      reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"SO_SETFIB":                         reflect.ValueOf(constant.MakeFromLiteral("4116", token.INT, 0)),
		"SO_SNDBUF":                         reflect.ValueOf(constant.MakeFromLiteral("4097", token.INT, 0)),
		"SO_SNDLOWAT":                       reflect.ValueOf(constant.MakeFromLiteral("4099", token.INT, 0)),
		"SO_SNDTIMEO":                       reflect.ValueOf(constant.MakeFromLiteral("4101", token.INT, 0)),
		"SO_TIMESTAMP":                      reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"SO_TYPE":                           reflect.ValueOf(constant.MakeFromLiteral("4104", token.INT, 0)),
		"SO_USELOOPBACK":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"SO_USER_COOKIE":                    reflect.ValueOf(constant.MakeFromLiteral("4117", token.INT, 0)),
		"SO_VENDOR":                         reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"SYS_ABORT2":                        reflect.ValueOf(constant.MakeFromLiteral("463", token.INT, 0)),
		"SYS_ACCEPT":                        reflect.ValueOf(constant.MakeFromLiteral("30", token.INT, 0)),
		"SYS_ACCEPT4":                       reflect.ValueOf(constant.MakeFromLiteral("541", token.INT, 0)),
		"SYS_ACCESS":                        reflect.ValueOf(constant.MakeFromLiteral("33", token.INT, 0)),
		"SYS_ACCT":                          reflect.ValueOf(constant.MakeFromLiteral("51", token.INT, 0)),
		"SYS_ADJTIME":                       reflect.ValueOf(constant.MakeFromLiteral("140", token.INT, 0)),
		"SYS_AIO_CANCEL":                    reflect.ValueOf(constant.MakeFromLiteral("316", token.INT, 0)),
		"SYS_AIO_ERROR":                     reflect.ValueOf(constant.MakeFromLiteral("317", token.INT, 0)),
		"SYS_AIO_FSYNC":                     reflect.ValueOf(constant.MakeFromLiteral("465", token.INT, 0)),
		"SYS_AIO_MLOCK":                     reflect.ValueOf(constant.MakeFromLiteral("543", token.INT, 0)),
		"SYS_AIO_READ":                      reflect.ValueOf(constant.MakeFromLiteral("255", token.INT, 0)),
		"SYS_AIO_RETURN":                    reflect.ValueOf(constant.MakeFromLiteral("314", token.INT, 0)),
		"SYS_AIO_SUSPEND":                   reflect.ValueOf(constant.MakeFromLiteral("315", token.INT, 0)),
		"SYS_AIO_WAITCOMPLETE":              reflect.ValueOf(constant.MakeFromLiteral("359", token.INT, 0)),
		"SYS_AIO_WRITE":                     reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"SYS_AUDIT":                         reflect.ValueOf(constant.MakeFromLiteral("445", token.INT, 0)),
		"SYS_AUDITCTL":                      reflect.ValueOf(constant.MakeFromLiteral("453", token.INT, 0)),
		"SYS_AUDITON":                       reflect.ValueOf(constant.MakeFromLiteral("446", token.INT, 0)),
		"SYS_BIND":                          reflect.ValueOf(constant.MakeFromLiteral("104", token.INT, 0)),
		"SYS_BINDAT":                        reflect.ValueOf(constant.MakeFromLiteral("538", token.INT, 0)),
		"SYS_CAP_ENTER":                     reflect.ValueOf(constant.MakeFromLiteral("516", token.INT, 0)),
		"SYS_CAP_FCNTLS_GET":                reflect.ValueOf(constant.MakeFromLiteral("537", token.INT, 0)),
		"SYS_CAP_FCNTLS_LIMIT":              reflect.ValueOf(constant.MakeFromLiteral("536", token.INT, 0)),
		"SYS_CAP_GETMODE":                   reflect.ValueOf(constant.MakeFromLiteral("517", token.INT, 0)),
		"SYS_CAP_IOCTLS_GET":                reflect.ValueOf(constant.MakeFromLiteral("535", token.INT, 0)),
		"SYS_CAP_IOCTLS_LIMIT":              reflect.ValueOf(constant.MakeFromLiteral("534", token.INT, 0)),
		"SYS_CAP_RIGHTS_LIMIT":              reflect.ValueOf(constant.MakeFromLiteral("533", token.INT, 0)),
		"SYS_CHDIR":                         reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SYS_CHFLAGS":                       reflect.ValueOf(constant.MakeFromLiteral("34", token.INT, 0)),
		"SYS_CHFLAGSAT":                     reflect.ValueOf(constant.MakeFromLiteral("540", token.INT, 0)),
		"SYS_CHMOD":                         reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"SYS_CHOWN":                         reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SYS_CHROOT":                        reflect.ValueOf(constant.MakeFromLiteral("61", token.INT, 0)),
		"SYS_CLOCK_GETCPUCLOCKID2":          reflect.ValueOf(constant.MakeFromLiteral("247", token.INT, 0)),
		"SYS_CLOCK_GETRES":                  reflect.ValueOf(constant.MakeFromLiteral("234", token.INT, 0)),
		"SYS_CLOCK_GETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("232", token.INT, 0)),
		"SYS_CLOCK_NANOSLEEP":               reflect.ValueOf(constant.MakeFromLiteral("244", token.INT, 0)),
		"SYS_CLOCK_SETTIME":                 reflect.ValueOf(constant.MakeFromLiteral("233", token.INT, 0)),
		"SYS_CLOSE":                         reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"SYS_CLOSEFROM":                     reflect.ValueOf(constant.MakeFromLiteral("509", token.INT, 0)),
		"SYS_CONNECT":                       reflect.ValueOf(constant.MakeFromLiteral("98", token.INT, 0)),
		"SYS_CONNECTAT":                     reflect.ValueOf(constant.MakeFromLiteral("539", token.INT, 0)),
		"SYS_CPUSET":                        reflect.ValueOf(constant.MakeFromLiteral("484", token.INT, 0)),
		"SYS_CPUSET_GETAFFINITY":            reflect.ValueOf(constant.MakeFromLiteral("487", token.INT, 0)),
		"SYS_CPUSET_GETID":                  reflect.ValueOf(constant.MakeFromLiteral("486", token.INT, 0)),
		"SYS_CPUSET_SETAFFINITY":            reflect.ValueOf(constant.MakeFromLiteral("488", token.INT, 0)),
		"SYS_CPUSET_SETID":                  reflect.ValueOf(constant.MakeFromLiteral("485", token.INT, 0)),
		"SYS_DUP":                           reflect.ValueOf(constant.MakeFromLiteral("41", token.INT, 0)),
		"SYS_DUP2":                          reflect.ValueOf(constant.MakeFromLiteral("90", token.INT, 0)),
		"SYS_EACCESS":                       reflect.ValueOf(constant.MakeFromLiteral("376", token.INT, 0)),
		"SYS_EXECVE":                        reflect.ValueOf(constant.MakeFromLiteral("59", token.INT, 0)),
		"SYS_EXIT":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"SYS_EXTATTRCTL":                    reflect.ValueOf(constant.MakeFromLiteral("355", token.INT, 0)),
		"SYS_EXTATTR_DELETE_FD":             reflect.ValueOf(constant.MakeFromLiteral("373", token.INT, 0)),
		"SYS_EXTATTR_DELETE_FILE":           reflect.ValueOf(constant.MakeFromLiteral("358", token.INT, 0)),
		"SYS_EXTATTR_DELETE_LINK":           reflect.ValueOf(constant.MakeFromLiteral("414", token.INT, 0)),
		"SYS_EXTATTR_GET_FD":                reflect.ValueOf(constant.MakeFromLiteral("372", token.INT, 0)),
		"SYS_EXTATTR_GET_FILE":              reflect.ValueOf(constant.MakeFromLiteral("357", token.INT, 0)),
		"SYS_EXTATTR_GET_LINK":              reflect.ValueOf(constant.MakeFromLiteral("413", token.INT, 0)),
		"SYS_EXTATTR_LIST_FD":               reflect.ValueOf(constant.MakeFromLiteral("437", token.INT, 0)),
		"SYS_EXTATTR_LIST_FILE":             reflect.ValueOf(constant.MakeFromLiteral("438", token.INT, 0)),
		"SYS_EXTATTR_LIST_LINK":             reflect.ValueOf(constant.MakeFromLiteral("439", token.INT, 0)),
		"SYS_EXTATTR_SET_FD":                reflect.ValueOf(constant.MakeFromLiteral("371", token.INT, 0)),
		"SYS_EXTATTR_SET_FILE":              reflect.ValueOf(constant.MakeFromLiteral("356", token.INT, 0)),
		"SYS_EXTATTR_SET_LINK":              reflect.ValueOf(constant.MakeFromLiteral("412", token.INT, 0)),
		"SYS_FACCESSAT":                     reflect.ValueOf(constant.MakeFromLiteral("489", token.INT, 0)),
		"SYS_FCHDIR":                        reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"SYS_FCHFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("35", token.INT, 0)),
		"SYS_FCHMOD":                        reflect.ValueOf(constant.MakeFromLiteral("124", token.INT, 0)),
		"SYS_FCHMODAT":                      reflect.ValueOf(constant.MakeFromLiteral("490", token.INT, 0)),
		"SYS_FCHOWN":                        reflect.ValueOf(constant.MakeFromLiteral("123", token.INT, 0)),
		"SYS_FCHOWNAT":                      reflect.ValueOf(constant.MakeFromLiteral("491", token.INT, 0)),
		"SYS_FCNTL":                         reflect.ValueOf(constant.MakeFromLiteral("92", token.INT, 0)),
		"SYS_FDATASYNC":                     reflect.ValueOf(constant.MakeFromLiteral("550", token.INT, 0)),
		"SYS_FEXECVE":                       reflect.ValueOf(constant.MakeFromLiteral("492", token.INT, 0)),
		"SYS_FFCLOCK_GETCOUNTER":            reflect.ValueOf(constant.MakeFromLiteral("241", token.INT, 0)),
		"SYS_FFCLOCK_GETESTIMATE":           reflect.ValueOf(constant.MakeFromLiteral("243", token.INT, 0)),
		"SYS_FFCLOCK_SETESTIMATE":           reflect.ValueOf(constant.MakeFromLiteral("242", token.INT, 0)),
		"SYS_FHOPEN":                        reflect.ValueOf(constant.MakeFromLiteral("298", token.INT, 0)),
		"SYS_FHSTAT":                        reflect.ValueOf(constant.MakeFromLiteral("299", token.INT, 0)),
		"SYS_FHSTATFS":                      reflect.ValueOf(constant.MakeFromLiteral("398", token.INT, 0)),
		"SYS_FLOCK":                         reflect.ValueOf(constant.MakeFromLiteral("131", token.INT, 0)),
		"SYS_FORK":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"SYS_FPATHCONF":                     reflect.ValueOf(constant.MakeFromLiteral("192", token.INT, 0)),
		"SYS_FSTAT":                         reflect.ValueOf(constant.MakeFromLiteral("551", token.INT, 0)),
		"SYS_FSTATAT":                       reflect.ValueOf(constant.MakeFromLiteral("552", token.INT, 0)),
		"SYS_FSTATFS":                       reflect.ValueOf(constant.MakeFromLiteral("556", token.INT, 0)),
		"SYS_FSYNC":                         reflect.ValueOf(constant.MakeFromLiteral("95", token.INT, 0)),
		"SYS_FTRUNCATE":                     reflect.ValueOf(constant.MakeFromLiteral("480", token.INT, 0)),
		"SYS_FUTIMENS":                      reflect.ValueOf(constant.MakeFromLiteral("546", token.INT, 0)),
		"SYS_FUTIMES":                       reflect.ValueOf(constant.MakeFromLiteral("206", token.INT, 0)),
		"SYS_FUTIMESAT":                     reflect.ValueOf(constant.MakeFromLiteral("494", token.INT, 0)),
		"SYS_GETAUDIT":                      reflect.ValueOf(constant.MakeFromLiteral("449", token.INT, 0)),
		"SYS_GETAUDIT_ADDR":                 reflect.ValueOf(constant.MakeFromLiteral("451", token.INT, 0)),
		"SYS_GETAUID":                       reflect.ValueOf(constant.MakeFromLiteral("447", token.INT, 0)),
		"SYS_GETCONTEXT":                    reflect.ValueOf(constant.MakeFromLiteral("421", token.INT, 0)),
		"SYS_GETDENTS":                      reflect.ValueOf(constant.MakeFromLiteral("272", token.INT, 0)),
		"SYS_GETDIRENTRIES":                 reflect.ValueOf(constant.MakeFromLiteral("554", token.INT, 0)),
		"SYS_GETDTABLESIZE":                 reflect.ValueOf(constant.MakeFromLiteral("89", token.INT, 0)),
		"SYS_GETEGID":                       reflect.ValueOf(constant.MakeFromLiteral("43", token.INT, 0)),
		"SYS_GETEUID":                       reflect.ValueOf(constant.MakeFromLiteral("25", token.INT, 0)),
		"SYS_GETFH":                         reflect.ValueOf(constant.MakeFromLiteral("161", token.INT, 0)),
		"SYS_GETFSSTAT":                     reflect.ValueOf(constant.MakeFromLiteral("557", token.INT, 0)),
		"SYS_GETGID":                        reflect.ValueOf(constant.MakeFromLiteral("47", token.INT, 0)),
		"SYS_GETGROUPS":                     reflect.ValueOf(constant.MakeFromLiteral("79", token.INT, 0)),
		"SYS_GETITIMER":                     reflect.ValueOf(constant.MakeFromLiteral("86", token.INT, 0)),
		"SYS_GETLOGIN":                      reflect.ValueOf(constant.MakeFromLiteral("49", token.INT, 0)),
		"SYS_GETLOGINCLASS":                 reflect.ValueOf(constant.MakeFromLiteral("523", token.INT, 0)),
		"SYS_GETPEERNAME":                   reflect.ValueOf(constant.MakeFromLiteral("31", token.INT, 0)),
		"SYS_GETPGID":                       reflect.ValueOf(constant.MakeFromLiteral("207", token.INT, 0)),
		"SYS_GETPGRP":                       reflect.ValueOf(constant.MakeFromLiteral("81", token.INT, 0)),
		"SYS_GETPID":                        reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SYS_GETPPID":                       reflect.ValueOf(constant.MakeFromLiteral("39", token.INT, 0)),
		"SYS_GETPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("100", token.INT, 0)),
		"SYS_GETRESGID":                     reflect.ValueOf(constant.MakeFromLiteral("361", token.INT, 0)),
		"SYS_GETRESUID":                     reflect.ValueOf(constant.MakeFromLiteral("360", token.INT, 0)),
		"SYS_GETRLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("194", token.INT, 0)),
		"SYS_GETRUSAGE":                     reflect.ValueOf(constant.MakeFromLiteral("117", token.INT, 0)),
		"SYS_GETSID":                        reflect.ValueOf(constant.MakeFromLiteral("310", token.INT, 0)),
		"SYS_GETSOCKNAME":                   reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SYS_GETSOCKOPT":                    reflect.ValueOf(constant.MakeFromLiteral("118", token.INT, 0)),
		"SYS_GETTIMEOFDAY":                  reflect.ValueOf(constant.MakeFromLiteral("116", token.INT, 0)),
		"SYS_GETUID":                        reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"SYS_GSSD_SYSCALL":                  reflect.ValueOf(constant.MakeFromLiteral("505", token.INT, 0)),
		"SYS_IOCTL":                         reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"SYS_ISSETUGID":                     reflect.ValueOf(constant.MakeFromLiteral("253", token.INT, 0)),
		"SYS_JAIL":                          reflect.ValueOf(constant.MakeFromLiteral("338", token.INT, 0)),
		"SYS_JAIL_ATTACH":                   reflect.ValueOf(constant.MakeFromLiteral("436", token.INT, 0)),
		"SYS_JAIL_GET":                      reflect.ValueOf(constant.MakeFromLiteral("506", token.INT, 0)),
		"SYS_JAIL_REMOVE":                   reflect.ValueOf(constant.MakeFromLiteral("508", token.INT, 0)),
		"SYS_JAIL_SET":                      reflect.ValueOf(constant.MakeFromLiteral("507", token.INT, 0)),
		"SYS_KENV":                          reflect.ValueOf(constant.MakeFromLiteral("390", token.INT, 0)),
		"SYS_KEVENT":                        reflect.ValueOf(constant.MakeFromLiteral("363", token.INT, 0)),
		"SYS_KILL":                          reflect.ValueOf(constant.MakeFromLiteral("37", token.INT, 0)),
		"SYS_KLDFIND":                       reflect.ValueOf(constant.MakeFromLiteral("306", token.INT, 0)),
		"SYS_KLDFIRSTMOD":                   reflect.ValueOf(constant.MakeFromLiteral("309", token.INT, 0)),
		"SYS_KLDLOAD":                       reflect.ValueOf(constant.MakeFromLiteral("304", token.INT, 0)),
		"SYS_KLDNEXT":                       reflect.ValueOf(constant.MakeFromLiteral("307", token.INT, 0)),
		"SYS_KLDSTAT":                       reflect.ValueOf(constant.MakeFromLiteral("308", token.INT, 0)),
		"SYS_KLDSYM":                        reflect.ValueOf(constant.MakeFromLiteral("337", token.INT, 0)),
		"SYS_KLDUNLOAD":                     reflect.ValueOf(constant.MakeFromLiteral("305", token.INT, 0)),
		"SYS_KLDUNLOADF":                    reflect.ValueOf(constant.MakeFromLiteral("444", token.INT, 0)),
		"SYS_KMQ_NOTIFY":                    reflect.ValueOf(constant.MakeFromLiteral("461", token.INT, 0)),
		"SYS_KMQ_OPEN":                      reflect.ValueOf(constant.MakeFromLiteral("457", token.INT, 0)),
		"SYS_KMQ_SETATTR":                   reflect.ValueOf(constant.MakeFromLiteral("458", token.INT, 0)),
		"SYS_KMQ_TIMEDRECEIVE":              reflect.ValueOf(constant.MakeFromLiteral("459", token.INT, 0)),
		"SYS_KMQ_TIMEDSEND":                 reflect.ValueOf(constant.MakeFromLiteral("460", token.INT, 0)),
		"SYS_KMQ_UNLINK":                    reflect.ValueOf(constant.MakeFromLiteral("462", token.INT, 0)),
		"SYS_KQUEUE":                        reflect.ValueOf(constant.MakeFromLiteral("362", token.INT, 0)),
		"SYS_KSEM_CLOSE":                    reflect.ValueOf(constant.MakeFromLiteral("400", token.INT, 0)),
		"SYS_KSEM_DESTROY":                  reflect.ValueOf(constant.MakeFromLiteral("408", token.INT, 0)),
		"SYS_KSEM_GETVALUE":                 reflect.ValueOf(constant.MakeFromLiteral("407", token.INT, 0)),
		"SYS_KSEM_INIT":                     reflect.ValueOf(constant.MakeFromLiteral("404", token.INT, 0)),
		"SYS_KSEM_OPEN":                     reflect.ValueOf(constant.MakeFromLiteral("405", token.INT, 0)),
		"SYS_KSEM_POST":                     reflect.ValueOf(constant.MakeFromLiteral("401", token.INT, 0)),
		"SYS_KSEM_TIMEDWAIT":                reflect.ValueOf(constant.MakeFromLiteral("441", token.INT, 0)),
		"SYS_KSEM_TRYWAIT":                  reflect.ValueOf(constant.MakeFromLiteral("403", token.INT, 0)),
		"SYS_KSEM_UNLINK":                   reflect.ValueOf(constant.MakeFromLiteral("406", token.INT, 0)),
		"SYS_KSEM_WAIT":                     reflect.ValueOf(constant.MakeFromLiteral("402", token.INT, 0)),
		"SYS_KTIMER_CREATE":                 reflect.ValueOf(constant.MakeFromLiteral("235", token.INT, 0)),
		"SYS_KTIMER_DELETE":                 reflect.ValueOf(constant.MakeFromLiteral("236", token.INT, 0)),
		"SYS_KTIMER_GETOVERRUN":             reflect.ValueOf(constant.MakeFromLiteral("239", token.INT, 0)),
		"SYS_KTIMER_GETTIME":                reflect.ValueOf(constant.MakeFromLiteral("238", token.INT, 0)),
		"SYS_KTIMER_SETTIME":                reflect.ValueOf(constant.MakeFromLiteral("237", token.INT, 0)),
		"SYS_KTRACE":                        reflect.ValueOf(constant.MakeFromLiteral("45", token.INT, 0)),
		"SYS_LCHFLAGS":                      reflect.ValueOf(constant.MakeFromLiteral("391", token.INT, 0)),
		"SYS_LCHMOD":                        reflect.ValueOf(constant.MakeFromLiteral("274", token.INT, 0)),
		"SYS_LCHOWN":                        reflect.ValueOf(constant.MakeFromLiteral("254", token.INT, 0)),
		"SYS_LGETFH":                        reflect.ValueOf(constant.MakeFromLiteral("160", token.INT, 0)),
		"SYS_LINK":                          reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"SYS_LINKAT":                        reflect.ValueOf(constant.MakeFromLiteral("495", token.INT, 0)),
		"SYS_LIO_LISTIO":                    reflect.ValueOf(constant.MakeFromLiteral("257", token.INT, 0)),
		"SYS_LISTEN":                        reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"SYS_LPATHCONF":                     reflect.ValueOf(constant.MakeFromLiteral("513", token.INT, 0)),
		"SYS_LSEEK":                         reflect.ValueOf(constant.MakeFromLiteral("478", token.INT, 0)),
		"SYS_LUTIMES":                       reflect.ValueOf(constant.MakeFromLiteral("276", token.INT, 0)),
		"SYS_MAC_SYSCALL":                   reflect.ValueOf(constant.MakeFromLiteral("394", token.INT, 0)),
		"SYS_MADVISE":                       reflect.ValueOf(constant.MakeFromLiteral("75", token.INT, 0)),
		"SYS_MINCORE":                       reflect.ValueOf(constant.MakeFromLiteral("78", token.INT, 0)),
		"SYS_MINHERIT":                      reflect.ValueOf(constant.MakeFromLiteral("250", token.INT, 0)),
		"SYS_MKDIR":                         reflect.ValueOf(constant.MakeFromLiteral("136", token.INT, 0)),
		"SYS_MKDIRAT":                       reflect.ValueOf(constant.MakeFromLiteral("496", token.INT, 0)),
		"SYS_MKFIFO":                        reflect.ValueOf(constant.MakeFromLiteral("132", token.INT, 0)),
		"SYS_MKFIFOAT":                      reflect.ValueOf(constant.MakeFromLiteral("497", token.INT, 0)),
		"SYS_MKNOD":                         reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"SYS_MKNODAT":                       reflect.ValueOf(constant.MakeFromLiteral("559", token.INT, 0)),
		"SYS_MLOCK":                         reflect.ValueOf(constant.MakeFromLiteral("203", token.INT, 0)),
		"SYS_MLOCKALL":                      reflect.ValueOf(constant.MakeFromLiteral("324", token.INT, 0)),
		"SYS_MMAP":                          reflect.ValueOf(constant.MakeFromLiteral("477", token.INT, 0)),
		"SYS_MODFIND":                       reflect.ValueOf(constant.MakeFromLiteral("303", token.INT, 0)),
		"SYS_MODFNEXT":                      reflect.ValueOf(constant.MakeFromLiteral("302", token.INT, 0)),
		"SYS_MODNEXT":                       reflect.ValueOf(constant.MakeFromLiteral("300", token.INT, 0)),
		"SYS_MODSTAT":                       reflect.ValueOf(constant.MakeFromLiteral("301", token.INT, 0)),
		"SYS_MOUNT":                         reflect.ValueOf(constant.MakeFromLiteral("21", token.INT, 0)),
		"SYS_MPROTECT":                      reflect.ValueOf(constant.MakeFromLiteral("74", token.INT, 0)),
		"SYS_MSGCTL":                        reflect.ValueOf(constant.MakeFromLiteral("511", token.INT, 0)),
		"SYS_MSGGET":                        reflect.ValueOf(constant.MakeFromLiteral("225", token.INT, 0)),
		"SYS_MSGRCV":                        reflect.ValueOf(constant.MakeFromLiteral("227", token.INT, 0)),
		"SYS_MSGSND":                        reflect.ValueOf(constant.MakeFromLiteral("226", token.INT, 0)),
		"SYS_MSGSYS":                        reflect.ValueOf(constant.MakeFromLiteral("170", token.INT, 0)),
		"SYS_MSYNC":                         reflect.ValueOf(constant.MakeFromLiteral("65", token.INT, 0)),
		"SYS_MUNLOCK":                       reflect.ValueOf(constant.MakeFromLiteral("204", token.INT, 0)),
		"SYS_MUNLOCKALL":                    reflect.ValueOf(constant.MakeFromLiteral("325", token.INT, 0)),
		"SYS_MUNMAP":                        reflect.ValueOf(constant.MakeFromLiteral("73", token.INT, 0)),
		"SYS_NANOSLEEP":                     reflect.ValueOf(constant.MakeFromLiteral("240", token.INT, 0)),
		"SYS_NFSSVC":                        reflect.ValueOf(constant.MakeFromLiteral("155", token.INT, 0)),
		"SYS_NFSTAT":                        reflect.ValueOf(constant.MakeFromLiteral("279", token.INT, 0)),
		"SYS_NLM_SYSCALL":                   reflect.ValueOf(constant.MakeFromLiteral("154", token.INT, 0)),
		"SYS_NLSTAT":                        reflect.ValueOf(constant.MakeFromLiteral("280", token.INT, 0)),
		"SYS_NMOUNT":                        reflect.ValueOf(constant.MakeFromLiteral("378", token.INT, 0)),
		"SYS_NSTAT":                         reflect.ValueOf(constant.MakeFromLiteral("278", token.INT, 0)),
		"SYS_NTP_ADJTIME":                   reflect.ValueOf(constant.MakeFromLiteral("176", token.INT, 0)),
		"SYS_NTP_GETTIME":                   reflect.ValueOf(constant.MakeFromLiteral("248", token.INT, 0)),
		"SYS_NUMA_GETAFFINITY":              reflect.ValueOf(constant.MakeFromLiteral("548", token.INT, 0)),
		"SYS_NUMA_SETAFFINITY":              reflect.ValueOf(constant.MakeFromLiteral("549", token.INT, 0)),
		"SYS_OBREAK":                        reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"SYS_OPEN":                          reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"SYS_OPENAT":                        reflect.ValueOf(constant.MakeFromLiteral("499", token.INT, 0)),
		"SYS_OPENBSD_POLL":                  reflect.ValueOf(constant.MakeFromLiteral("252", token.INT, 0)),
		"SYS_OVADVISE":                      reflect.ValueOf(constant.MakeFromLiteral("72", token.INT, 0)),
		"SYS_PATHCONF":                      reflect.ValueOf(constant.MakeFromLiteral("191", token.INT, 0)),
		"SYS_PDFORK":                        reflect.ValueOf(constant.MakeFromLiteral("518", token.INT, 0)),
		"SYS_PDGETPID":                      reflect.ValueOf(constant.MakeFromLiteral("520", token.INT, 0)),
		"SYS_PDKILL":                        reflect.ValueOf(constant.MakeFromLiteral("519", token.INT, 0)),
		"SYS_PIPE":                          reflect.ValueOf(constant.MakeFromLiteral("42", token.INT, 0)),
		"SYS_PIPE2":                         reflect.ValueOf(constant.MakeFromLiteral("542", token.INT, 0)),
		"SYS_POLL":                          reflect.ValueOf(constant.MakeFromLiteral("209", token.INT, 0)),
		"SYS_POSIX_FADVISE":                 reflect.ValueOf(constant.MakeFromLiteral("531", token.INT, 0)),
		"SYS_POSIX_FALLOCATE":               reflect.ValueOf(constant.MakeFromLiteral("530", token.INT, 0)),
		"SYS_POSIX_OPENPT":                  reflect.ValueOf(constant.MakeFromLiteral("504", token.INT, 0)),
		"SYS_PPOLL":                         reflect.ValueOf(constant.MakeFromLiteral("545", token.INT, 0)),
		"SYS_PREAD":                         reflect.ValueOf(constant.MakeFromLiteral("475", token.INT, 0)),
		"SYS_PREADV":                        reflect.ValueOf(constant.MakeFromLiteral("289", token.INT, 0)),
		"SYS_PROCCTL":                       reflect.ValueOf(constant.MakeFromLiteral("544", token.INT, 0)),
		"SYS_PROFIL":                        reflect.ValueOf(constant.MakeFromLiteral("44", token.INT, 0)),
		"SYS_PSELECT":                       reflect.ValueOf(constant.MakeFromLiteral("522", token.INT, 0)),
		"SYS_PTRACE":                        reflect.ValueOf(constant.MakeFromLiteral("26", token.INT, 0)),
		"SYS_PWRITE":                        reflect.ValueOf(constant.MakeFromLiteral("476", token.INT, 0)),
		"SYS_PWRITEV":                       reflect.ValueOf(constant.MakeFromLiteral("290", token.INT, 0)),
		"SYS_QUOTACTL":                      reflect.ValueOf(constant.MakeFromLiteral("148", token.INT, 0)),
		"SYS_RCTL_ADD_RULE":                 reflect.ValueOf(constant.MakeFromLiteral("528", token.INT, 0)),
		"SYS_RCTL_GET_LIMITS":               reflect.ValueOf(constant.MakeFromLiteral("527", token.INT, 0)),
		"SYS_RCTL_GET_RACCT":                reflect.ValueOf(constant.MakeFromLiteral("525", token.INT, 0)),
		"SYS_RCTL_GET_RULES":                reflect.ValueOf(constant.MakeFromLiteral("526", token.INT, 0)),
		"SYS_RCTL_REMOVE_RULE":              reflect.ValueOf(constant.MakeFromLiteral("529", token.INT, 0)),
		"SYS_READ":                          reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"SYS_READLINK":                      reflect.ValueOf(constant.MakeFromLiteral("58", token.INT, 0)),
		"SYS_READLINKAT":                    reflect.ValueOf(constant.MakeFromLiteral("500", token.INT, 0)),
		"SYS_READV":                         reflect.ValueOf(constant.MakeFromLiteral("120", token.INT, 0)),
		"SYS_REBOOT":                        reflect.ValueOf(constant.MakeFromLiteral("55", token.INT, 0)),
		"SYS_RECVFROM":                      reflect.ValueOf(constant.MakeFromLiteral("29", token.INT, 0)),
		"SYS_RECVMSG":                       reflect.ValueOf(constant.MakeFromLiteral("27", token.INT, 0)),
		"SYS_RENAME":                        reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"SYS_RENAMEAT":                      reflect.ValueOf(constant.MakeFromLiteral("501", token.INT, 0)),
		"SYS_REVOKE":                        reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"SYS_RFORK":                         reflect.ValueOf(constant.MakeFromLiteral("251", token.INT, 0)),
		"SYS_RMDIR":                         reflect.ValueOf(constant.MakeFromLiteral("137", token.INT, 0)),
		"SYS_RTPRIO":                        reflect.ValueOf(constant.MakeFromLiteral("166", token.INT, 0)),
		"SYS_RTPRIO_THREAD":                 reflect.ValueOf(constant.MakeFromLiteral("466", token.INT, 0)),
		"SYS_SBRK":                          reflect.ValueOf(constant.MakeFromLiteral("69", token.INT, 0)),
		"SYS_SCHED_GETPARAM":                reflect.ValueOf(constant.MakeFromLiteral("328", token.INT, 0)),
		"SYS_SCHED_GETSCHEDULER":            reflect.ValueOf(constant.MakeFromLiteral("330", token.INT, 0)),
		"SYS_SCHED_GET_PRIORITY_MAX":        reflect.ValueOf(constant.MakeFromLiteral("332", token.INT, 0)),
		"SYS_SCHED_GET_PRIORITY_MIN":        reflect.ValueOf(constant.MakeFromLiteral("333", token.INT, 0)),
		"SYS_SCHED_RR_GET_INTERVAL":         reflect.ValueOf(constant.MakeFromLiteral("334", token.INT, 0)),
		"SYS_SCHED_SETPARAM":                reflect.ValueOf(constant.MakeFromLiteral("327", token.INT, 0)),
		"SYS_SCHED_SETSCHEDULER":            reflect.ValueOf(constant.MakeFromLiteral("329", token.INT, 0)),
		"SYS_SCHED_YIELD":                   reflect.ValueOf(constant.MakeFromLiteral("331", token.INT, 0)),
		"SYS_SCTP_GENERIC_RECVMSG":          reflect.ValueOf(constant.MakeFromLiteral("474", token.INT, 0)),
		"SYS_SCTP_GENERIC_SENDMSG":          reflect.ValueOf(constant.MakeFromLiteral("472", token.INT, 0)),
		"SYS_SCTP_GENERIC_SENDMSG_IOV":      reflect.ValueOf(constant.MakeFromLiteral("473", token.INT, 0)),
		"SYS_SCTP_PEELOFF":                  reflect.ValueOf(constant.MakeFromLiteral("471", token.INT, 0)),
		"SYS_SELECT":                        reflect.ValueOf(constant.MakeFromLiteral("93", token.INT, 0)),
		"SYS_SEMGET":                        reflect.ValueOf(constant.MakeFromLiteral("221", token.INT, 0)),
		"SYS_SEMOP":                         reflect.ValueOf(constant.MakeFromLiteral("222", token.INT, 0)),
		"SYS_SEMSYS":                        reflect.ValueOf(constant.MakeFromLiteral("169", token.INT, 0)),
		"SYS_SENDFILE":                      reflect.ValueOf(constant.MakeFromLiteral("393", token.INT, 0)),
		"SYS_SENDMSG":                       reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SYS_SENDTO":                        reflect.ValueOf(constant.MakeFromLiteral("133", token.INT, 0)),
		"SYS_SETAUDIT":                      reflect.ValueOf(constant.MakeFromLiteral("450", token.INT, 0)),
		"SYS_SETAUDIT_ADDR":                 reflect.ValueOf(constant.MakeFromLiteral("452", token.INT, 0)),
		"SYS_SETAUID":                       reflect.ValueOf(constant.MakeFromLiteral("448", token.INT, 0)),
		"SYS_SETCONTEXT":                    reflect.ValueOf(constant.MakeFromLiteral("422", token.INT, 0)),
		"SYS_SETEGID":                       reflect.ValueOf(constant.MakeFromLiteral("182", token.INT, 0)),
		"SYS_SETEUID":                       reflect.ValueOf(constant.MakeFromLiteral("183", token.INT, 0)),
		"SYS_SETFIB":                        reflect.ValueOf(constant.MakeFromLiteral("175", token.INT, 0)),
		"SYS_SETGID":                        reflect.ValueOf(constant.MakeFromLiteral("181", token.INT, 0)),
		"SYS_SETGROUPS":                     reflect.ValueOf(constant.MakeFromLiteral("80", token.INT, 0)),
		"SYS_SETITIMER":                     reflect.ValueOf(constant.MakeFromLiteral("83", token.INT, 0)),
		"SYS_SETLOGIN":                      reflect.ValueOf(constant.MakeFromLiteral("50", token.INT, 0)),
		"SYS_SETLOGINCLASS":                 reflect.ValueOf(constant.MakeFromLiteral("524", token.INT, 0)),
		"SYS_SETPGID":                       reflect.ValueOf(constant.MakeFromLiteral("82", token.INT, 0)),
		"SYS_SETPRIORITY":                   reflect.ValueOf(constant.MakeFromLiteral("96", token.INT, 0)),
		"SYS_SETREGID":                      reflect.ValueOf(constant.MakeFromLiteral("127", token.INT, 0)),
		"SYS_SETRESGID":                     reflect.ValueOf(constant.MakeFromLiteral("312", token.INT, 0)),
		"SYS_SETRESUID":                     reflect.ValueOf(constant.MakeFromLiteral("311", token.INT, 0)),
		"SYS_SETREUID":                      reflect.ValueOf(constant.MakeFromLiteral("126", token.INT, 0)),
		"SYS_SETRLIMIT":                     reflect.ValueOf(constant.MakeFromLiteral("195", token.INT, 0)),
		"SYS_SETSID":                        reflect.ValueOf(constant.MakeFromLiteral("147", token.INT, 0)),
		"SYS_SETSOCKOPT":                    reflect.ValueOf(constant.MakeFromLiteral("105", token.INT, 0)),
		"SYS_SETTIMEOFDAY":                  reflect.ValueOf(constant.MakeFromLiteral("122", token.INT, 0)),
		"SYS_SETUID":                        reflect.ValueOf(constant.MakeFromLiteral("23", token.INT, 0)),
		"SYS_SHMAT":                         reflect.ValueOf(constant.MakeFromLiteral("228", token.INT, 0)),
		"SYS_SHMCTL":                        reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"SYS_SHMDT":                         reflect.ValueOf(constant.MakeFromLiteral("230", token.INT, 0)),
		"SYS_SHMGET":                        reflect.ValueOf(constant.MakeFromLiteral("231", token.INT, 0)),
		"SYS_SHMSYS":                        reflect.ValueOf(constant.MakeFromLiteral("171", token.INT, 0)),
		"SYS_SHM_OPEN":                      reflect.ValueOf(constant.MakeFromLiteral("482", token.INT, 0)),
		"SYS_SHM_UNLINK":                    reflect.ValueOf(constant.MakeFromLiteral("483", token.INT, 0)),
		"SYS_SHUTDOWN":                      reflect.ValueOf(constant.MakeFromLiteral("134", token.INT, 0)),
		"SYS_SIGACTION":                     reflect.ValueOf(constant.MakeFromLiteral("416", token.INT, 0)),
		"SYS_SIGALTSTACK":                   reflect.ValueOf(constant.MakeFromLiteral("53", token.INT, 0)),
		"SYS_SIGPENDING":                    reflect.ValueOf(constant.MakeFromLiteral("343", token.INT, 0)),
		"SYS_SIGPROCMASK":                   reflect.ValueOf(constant.MakeFromLiteral("340", token.INT, 0)),
		"SYS_SIGQUEUE":                      reflect.ValueOf(constant.MakeFromLiteral("456", token.INT, 0)),
		"SYS_SIGRETURN":                     reflect.ValueOf(constant.MakeFromLiteral("417", token.INT, 0)),
		"SYS_SIGSUSPEND":                    reflect.ValueOf(constant.MakeFromLiteral("341", token.INT, 0)),
		"SYS_SIGTIMEDWAIT":                  reflect.ValueOf(constant.MakeFromLiteral("345", token.INT, 0)),
		"SYS_SIGWAIT":                       reflect.ValueOf(constant.MakeFromLiteral("429", token.INT, 0)),
		"SYS_SIGWAITINFO":                   reflect.ValueOf(constant.MakeFromLiteral("346", token.INT, 0)),
		"SYS_SOCKET":                        reflect.ValueOf(constant.MakeFromLiteral("97", token.INT, 0)),
		"SYS_SOCKETPAIR":                    reflect.ValueOf(constant.MakeFromLiteral("135", token.INT, 0)),
		"SYS_SSTK":                          reflect.ValueOf(constant.MakeFromLiteral("70", token.INT, 0)),
		"SYS_STATFS":                        reflect.ValueOf(constant.MakeFromLiteral("555", token.INT, 0)),
		"SYS_SWAPCONTEXT":                   reflect.ValueOf(constant.MakeFromLiteral("423", token.INT, 0)),
		"SYS_SWAPOFF":                       reflect.ValueOf(constant.MakeFromLiteral("424", token.INT, 0)),
		"SYS_SWAPON":                        reflect.ValueOf(constant.MakeFromLiteral("85", token.INT, 0)),
		"SYS_SYMLINK":                       reflect.ValueOf(constant.MakeFromLiteral("57", token.INT, 0)),
		"SYS_SYMLINKAT":                     reflect.ValueOf(constant.MakeFromLiteral("502", token.INT, 0)),
		"SYS_SYNC":                          reflect.ValueOf(constant.MakeFromLiteral("36", token.INT, 0)),
		"SYS_SYSARCH":                       reflect.ValueOf(constant.MakeFromLiteral("165", token.INT, 0)),
		"SYS_THR_CREATE":                    reflect.ValueOf(constant.MakeFromLiteral("430", token.INT, 0)),
		"SYS_THR_EXIT":                      reflect.ValueOf(constant.MakeFromLiteral("431", token.INT, 0)),
		"SYS_THR_KILL":                      reflect.ValueOf(constant.MakeFromLiteral("433", token.INT, 0)),
		"SYS_THR_KILL2":                     reflect.ValueOf(constant.MakeFromLiteral("481", token.INT, 0)),
		"SYS_THR_NEW":                       reflect.ValueOf(constant.MakeFromLiteral("455", token.INT, 0)),
		"SYS_THR_SELF":                      reflect.ValueOf(constant.MakeFromLiteral("432", token.INT, 0)),
		"SYS_THR_SET_NAME":                  reflect.ValueOf(constant.MakeFromLiteral("464", token.INT, 0)),
		"SYS_THR_SUSPEND":                   reflect.ValueOf(constant.MakeFromLiteral("442", token.INT, 0)),
		"SYS_THR_WAKE":                      reflect.ValueOf(constant.MakeFromLiteral("443", token.INT, 0)),
		"SYS_TRUNCATE":                      reflect.ValueOf(constant.MakeFromLiteral("479", token.INT, 0)),
		"SYS_UMASK":                         reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"SYS_UNDELETE":                      reflect.ValueOf(constant.MakeFromLiteral("205", token.INT, 0)),
		"SYS_UNLINK":                        reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"SYS_UNLINKAT":                      reflect.ValueOf(constant.MakeFromLiteral("503", token.INT, 0)),
		"SYS_UNMOUNT":                       reflect.ValueOf(constant.MakeFromLiteral("22", token.INT, 0)),
		"SYS_UTIMENSAT":                     reflect.ValueOf(constant.MakeFromLiteral("547", token.INT, 0)),
		"SYS_UTIMES":                        reflect.ValueOf(constant.MakeFromLiteral("138", token.INT, 0)),
		"SYS_UTRACE":                        reflect.ValueOf(constant.MakeFromLiteral("335", token.INT, 0)),
		"SYS_UUIDGEN":                       reflect.ValueOf(constant.MakeFromLiteral("392", token.INT, 0)),
		"SYS_VFORK":                         reflect.ValueOf(constant.MakeFromLiteral("66", token.INT, 0)),
		"SYS_WAIT4":                         reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"SYS_WAIT6":                         reflect.ValueOf(constant.MakeFromLiteral("532", token.INT, 0)),
		"SYS_WRITE":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SYS_WRITEV":                        reflect.ValueOf(constant.MakeFromLiteral("121", token.INT, 0)),
		"SYS_YIELD":                         reflect.ValueOf(constant.MakeFromLiteral("321", token.INT, 0)),
		"SYS__UMTX_OP":                      reflect.ValueOf(constant.MakeFromLiteral("454", token.INT, 0)),
		"SYS___ACL_ACLCHECK_FD":             reflect.ValueOf(constant.MakeFromLiteral("354", token.INT, 0)),
		"SYS___ACL_ACLCHECK_FILE":           reflect.ValueOf(constant.MakeFromLiteral("353", token.INT, 0)),
		"SYS___ACL_ACLCHECK_LINK":           reflect.ValueOf(constant.MakeFromLiteral("428", token.INT, 0)),
		"SYS___ACL_DELETE_FD":               reflect.ValueOf(constant.MakeFromLiteral("352", token.INT, 0)),
		"SYS___ACL_DELETE_FILE":             reflect.ValueOf(constant.MakeFromLiteral("351", token.INT, 0)),
		"SYS___ACL_DELETE_LINK":             reflect.ValueOf(constant.MakeFromLiteral("427", token.INT, 0)),
		"SYS___ACL_GET_FD":                  reflect.ValueOf(constant.MakeFromLiteral("349", token.INT, 0)),
		"SYS___ACL_GET_FILE":                reflect.ValueOf(constant.MakeFromLiteral("347", token.INT, 0)),
		"SYS___ACL_GET_LINK":                reflect.ValueOf(constant.MakeFromLiteral("425", token.INT, 0)),
		"SYS___ACL_SET_FD":                  reflect.ValueOf(constant.MakeFromLiteral("350", token.INT, 0)),
		"SYS___ACL_SET_FILE":                reflect.ValueOf(constant.MakeFromLiteral("348", token.INT, 0)),
		"SYS___ACL_SET_LINK":                reflect.ValueOf(constant.MakeFromLiteral("426", token.INT, 0)),
		"SYS___CAP_RIGHTS_GET":              reflect.ValueOf(constant.MakeFromLiteral("515", token.INT, 0)),
		"SYS___GETCWD":                      reflect.ValueOf(constant.MakeFromLiteral("326", token.INT, 0)),
		"SYS___MAC_EXECVE":                  reflect.ValueOf(constant.MakeFromLiteral("415", token.INT, 0)),
		"SYS___MAC_GET_FD":                  reflect.ValueOf(constant.MakeFromLiteral("386", token.INT, 0)),
		"SYS___MAC_GET_FILE":                reflect.ValueOf(constant.MakeFromLiteral("387", token.INT, 0)),
		"SYS___MAC_GET_LINK":                reflect.ValueOf(constant.MakeFromLiteral("410", token.INT, 0)),
		"SYS___MAC_GET_PID":                 reflect.ValueOf(constant.MakeFromLiteral("409", token.INT, 0)),
		"SYS___MAC_GET_PROC":                reflect.ValueOf(constant.MakeFromLiteral("384", token.INT, 0)),
		"SYS___MAC_SET_FD":                  reflect.ValueOf(constant.MakeFromLiteral("388", token.INT, 0)),
		"SYS___MAC_SET_FILE":                reflect.ValueOf(constant.MakeFromLiteral("389", token.INT, 0)),
		"SYS___MAC_SET_LINK":                reflect.ValueOf(constant.MakeFromLiteral("411", token.INT, 0)),
		"SYS___MAC_SET_PROC":                reflect.ValueOf(constant.MakeFromLiteral("385", token.INT, 0)),
		"SYS___SEMCTL":                      reflect.ValueOf(constant.MakeFromLiteral("510", token.INT, 0)),
		"SYS___SETUGID":                     reflect.ValueOf(constant.MakeFromLiteral("374", token.INT, 0)),
		"SYS___SYSCTL":                      reflect.ValueOf(constant.MakeFromLiteral("202", token.INT, 0)),
		"S_IFBLK":                           reflect.ValueOf(constant.MakeFromLiteral("24576", token.INT, 0)),
		"S_IFCHR":                           reflect.ValueOf(constant.MakeFromLiteral("8192", token.INT, 0)),
		"S_IFDIR":                           reflect.ValueOf(constant.MakeFromLiteral("16384", token.INT, 0)),
		"S_IFIFO":                           reflect.ValueOf(constant.MakeFromLiteral("4096", token.INT, 0)),
		"S_IFLNK":                           reflect.ValueOf(constant.MakeFromLiteral("40960", token.INT, 0)),
		"S_IFMT":                            reflect.ValueOf(constant.MakeFromLiteral("61440", token.INT, 0)),
		"S_IFREG":                           reflect.ValueOf(constant.MakeFromLiteral("32768", token.INT, 0)),
		"S_IFSOCK":                          reflect.ValueOf(constant.MakeFromLiteral("49152", token.INT, 0)),
		"S_IRUSR":                           reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"S_IRWXG":                           reflect.ValueOf(constant.MakeFromLiteral("56", token.INT, 0)),
		"S_IRWXO":                           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"S_ISGID":                           reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"S_ISUID":                           reflect.ValueOf(constant.MakeFromLiteral("2048", token.INT, 0)),
		"S_ISVTX":                           reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"S_IWUSR":                           reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"S_IXUSR":                           reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"Seek":                              reflect.ValueOf(syscall.Seek),
		"Select":                            reflect.ValueOf(syscall.Select),
		"Sendfile":                          reflect.ValueOf(syscall.Sendfile),
		"Sendmsg":                           reflect.ValueOf(syscall.Sendmsg),
		"SendmsgN":                          reflect.ValueOf(syscall.SendmsgN),
		"Sendto":                            reflect.ValueOf(syscall.Sendto),
		"SetBpf":                            reflect.ValueOf(syscall.SetBpf),
		"SetBpfBuflen":                      reflect.ValueOf(syscall.SetBpfBuflen),
		"SetBpfDatalink":                    reflect.ValueOf(syscall.SetBpfDatalink),
		"SetBpfHeadercmpl":                  reflect.ValueOf(syscall.SetBpfHeadercmpl),
		"SetBpfImmediate":                   reflect.ValueOf(syscall.SetBpfImmediate),
		"SetBpfInterface":                   reflect.ValueOf(syscall.SetBpfInterface),
		"SetBpfPromisc":                     reflect.ValueOf(syscall.SetBpfPromisc),
		"SetBpfTimeout":                     reflect.ValueOf(syscall.SetBpfTimeout),
		"SetKevent":                         reflect.ValueOf(syscall.SetKevent),
		"SetNonblock":                       reflect.ValueOf(syscall.SetNonblock),
		"Setegid":                           reflect.ValueOf(syscall.Setegid),
		"Setenv":                            reflect.ValueOf(syscall.Setenv),
		"Seteuid":                           reflect.ValueOf(syscall.Seteuid),
		"Setgid":                            reflect.ValueOf(syscall.Setgid),
		"Setgroups":                         reflect.ValueOf(syscall.Setgroups),
		"Setlogin":                          reflect.ValueOf(syscall.Setlogin),
		"Setpgid":                           reflect.ValueOf(syscall.Setpgid),
		"Setpriority":                       reflect.ValueOf(syscall.Setpriority),
		"Setregid":                          reflect.ValueOf(syscall.Setregid),
		"Setreuid":                          reflect.ValueOf(syscall.Setreuid),
		"Setrlimit":                         reflect.ValueOf(syscall.Setrlimit),
		"Setsid":                            reflect.ValueOf(syscall.Setsid),
		"SetsockoptByte":                    reflect.ValueOf(syscall.SetsockoptByte),
		"SetsockoptICMPv6Filter":            reflect.ValueOf(syscall.SetsockoptICMPv6Filter),
		"SetsockoptIPMreq":                  reflect.ValueOf(syscall.SetsockoptIPMreq),
		"SetsockoptIPMreqn":                 reflect.ValueOf(syscall.SetsockoptIPMreqn),
		"SetsockoptIPv6Mreq":                reflect.ValueOf(syscall.SetsockoptIPv6Mreq),
		"SetsockoptInet4Addr":               reflect.ValueOf(syscall.SetsockoptInet4Addr),
		"SetsockoptInt":                     reflect.ValueOf(syscall.SetsockoptInt),
		"SetsockoptLinger":                  reflect.ValueOf(syscall.SetsockoptLinger),
		"SetsockoptString":                  reflect.ValueOf(syscall.SetsockoptString),
		"SetsockoptTimeval":                 reflect.ValueOf(syscall.SetsockoptTimeval),
		"Settimeofday":                      reflect.ValueOf(syscall.Settimeofday),
		"Setuid":                            reflect.ValueOf(syscall.Setuid),
		"SizeofBpfHdr":                      reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofBpfInsn":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofBpfProgram":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofBpfStat":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofBpfVersion":                  reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"SizeofBpfZbuf":                     reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"SizeofBpfZbufHeader":               reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofCmsghdr":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofICMPv6Filter":                reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPMreq":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofIPMreqn":                     reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"SizeofIPv6MTUInfo":                 reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"SizeofIPv6Mreq":                    reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofIfAnnounceMsghdr":            reflect.ValueOf(constant.MakeFromLiteral("24", token.INT, 0)),
		"SizeofIfData":                      reflect.ValueOf(constant.MakeFromLiteral("152", token.INT, 0)),
		"SizeofIfMsghdr":                    reflect.ValueOf(constant.MakeFromLiteral("168", token.INT, 0)),
		"SizeofIfaMsghdr":                   reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofIfmaMsghdr":                  reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofInet6Pktinfo":                reflect.ValueOf(constant.MakeFromLiteral("20", token.INT, 0)),
		"SizeofLinger":                      reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"SizeofMsghdr":                      reflect.ValueOf(constant.MakeFromLiteral("48", token.INT, 0)),
		"SizeofRtMetrics":                   reflect.ValueOf(constant.MakeFromLiteral("112", token.INT, 0)),
		"SizeofRtMsghdr":                    reflect.ValueOf(constant.MakeFromLiteral("152", token.INT, 0)),
		"SizeofSockaddrAny":                 reflect.ValueOf(constant.MakeFromLiteral("108", token.INT, 0)),
		"SizeofSockaddrDatalink":            reflect.ValueOf(constant.MakeFromLiteral("54", token.INT, 0)),
		"SizeofSockaddrInet4":               reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"SizeofSockaddrInet6":               reflect.ValueOf(constant.MakeFromLiteral("28", token.INT, 0)),
		"SizeofSockaddrUnix":                reflect.ValueOf(constant.MakeFromLiteral("106", token.INT, 0)),
		"SlicePtrFromStrings":               reflect.ValueOf(syscall.SlicePtrFromStrings),
		"Socket":                            reflect.ValueOf(syscall.Socket),
		"SocketDisableIPv6":                 reflect.ValueOf(&syscall.SocketDisableIPv6).Elem(),
		"Socketpair":                        reflect.ValueOf(syscall.Socketpair),
		"Stat":                              reflect.ValueOf(syscall.Stat),
		"Statfs":                            reflect.ValueOf(syscall.Statfs),
		"Stderr":                            reflect.ValueOf(&syscall.Stderr).Elem(),
		"Stdin":                             reflect.ValueOf(&syscall.Stdin).Elem(),
		"Stdout":                            reflect.ValueOf(&syscall.Stdout).Elem(),
		"StringBytePtr":                     reflect.ValueOf(syscall.StringBytePtr),
		"StringByteSlice":                   reflect.ValueOf(syscall.StringByteSlice),
		"StringSlicePtr":                    reflect.ValueOf(syscall.StringSlicePtr),
		"Symlink":                           reflect.ValueOf(syscall.Symlink),
		"Sync":                              reflect.ValueOf(syscall.Sync),
		"Sysctl":                            reflect.ValueOf(syscall.Sysctl),
		"SysctlUint32":                      reflect.ValueOf(syscall.SysctlUint32),
		"TCIFLUSH":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCIOFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"TCOFLUSH":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_CA_NAME_MAX":                   reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TCP_CONGESTION":                    reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TCP_INFO":                          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TCP_KEEPCNT":                       reflect.ValueOf(constant.MakeFromLiteral("1024", token.INT, 0)),
		"TCP_KEEPIDLE":                      reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TCP_KEEPINIT":                      reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TCP_KEEPINTVL":                     reflect.ValueOf(constant.MakeFromLiteral("512", token.INT, 0)),
		"TCP_MAXBURST":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_MAXHLEN":                       reflect.ValueOf(constant.MakeFromLiteral("60", token.INT, 0)),
		"TCP_MAXOLEN":                       reflect.ValueOf(constant.MakeFromLiteral("40", token.INT, 0)),
		"TCP_MAXSEG":                        reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TCP_MAXWIN":                        reflect.ValueOf(constant.MakeFromLiteral("65535", token.INT, 0)),
		"TCP_MAX_SACK":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_MAX_WINSHIFT":                  reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"TCP_MD5SIG":                        reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TCP_MINMSS":                        reflect.ValueOf(constant.MakeFromLiteral("216", token.INT, 0)),
		"TCP_MSS":                           reflect.ValueOf(constant.MakeFromLiteral("536", token.INT, 0)),
		"TCP_NODELAY":                       reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TCP_NOOPT":                         reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TCP_NOPUSH":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TCP_VENDOR":                        reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"TCSAFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCCBRK":                          reflect.ValueOf(constant.MakeFromLiteral("536900730", token.INT, 0)),
		"TIOCCDTR":                          reflect.ValueOf(constant.MakeFromLiteral("536900728", token.INT, 0)),
		"TIOCCONS":                          reflect.ValueOf(constant.MakeFromLiteral("2147775586", token.INT, 0)),
		"TIOCDRAIN":                         reflect.ValueOf(constant.MakeFromLiteral("536900702", token.INT, 0)),
		"TIOCEXCL":                          reflect.ValueOf(constant.MakeFromLiteral("536900621", token.INT, 0)),
		"TIOCEXT":                           reflect.ValueOf(constant.MakeFromLiteral("2147775584", token.INT, 0)),
		"TIOCFLUSH":                         reflect.ValueOf(constant.MakeFromLiteral("2147775504", token.INT, 0)),
		"TIOCGDRAINWAIT":                    reflect.ValueOf(constant.MakeFromLiteral("1074033750", token.INT, 0)),
		"TIOCGETA":                          reflect.ValueOf(constant.MakeFromLiteral("1076655123", token.INT, 0)),
		"TIOCGETD":                          reflect.ValueOf(constant.MakeFromLiteral("1074033690", token.INT, 0)),
		"TIOCGPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("1074033783", token.INT, 0)),
		"TIOCGPTN":                          reflect.ValueOf(constant.MakeFromLiteral("1074033679", token.INT, 0)),
		"TIOCGSID":                          reflect.ValueOf(constant.MakeFromLiteral("1074033763", token.INT, 0)),
		"TIOCGWINSZ":                        reflect.ValueOf(constant.MakeFromLiteral("1074295912", token.INT, 0)),
		"TIOCMBIC":                          reflect.ValueOf(constant.MakeFromLiteral("2147775595", token.INT, 0)),
		"TIOCMBIS":                          reflect.ValueOf(constant.MakeFromLiteral("2147775596", token.INT, 0)),
		"TIOCMGDTRWAIT":                     reflect.ValueOf(constant.MakeFromLiteral("1074033754", token.INT, 0)),
		"TIOCMGET":                          reflect.ValueOf(constant.MakeFromLiteral("1074033770", token.INT, 0)),
		"TIOCMSDTRWAIT":                     reflect.ValueOf(constant.MakeFromLiteral("2147775579", token.INT, 0)),
		"TIOCMSET":                          reflect.ValueOf(constant.MakeFromLiteral("2147775597", token.INT, 0)),
		"TIOCM_CAR":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CD":                          reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_CTS":                         reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCM_DCD":                         reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCM_DSR":                         reflect.ValueOf(constant.MakeFromLiteral("256", token.INT, 0)),
		"TIOCM_DTR":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCM_LE":                          reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCM_RI":                          reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RNG":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"TIOCM_RTS":                         reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCM_SR":                          reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCM_ST":                          reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCNOTTY":                         reflect.ValueOf(constant.MakeFromLiteral("536900721", token.INT, 0)),
		"TIOCNXCL":                          reflect.ValueOf(constant.MakeFromLiteral("536900622", token.INT, 0)),
		"TIOCOUTQ":                          reflect.ValueOf(constant.MakeFromLiteral("1074033779", token.INT, 0)),
		"TIOCPKT":                           reflect.ValueOf(constant.MakeFromLiteral("2147775600", token.INT, 0)),
		"TIOCPKT_DATA":                      reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"TIOCPKT_DOSTOP":                    reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"TIOCPKT_FLUSHREAD":                 reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"TIOCPKT_FLUSHWRITE":                reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"TIOCPKT_IOCTL":                     reflect.ValueOf(constant.MakeFromLiteral("64", token.INT, 0)),
		"TIOCPKT_NOSTOP":                    reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"TIOCPKT_START":                     reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"TIOCPKT_STOP":                      reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"TIOCPTMASTER":                      reflect.ValueOf(constant.MakeFromLiteral("536900636", token.INT, 0)),
		"TIOCSBRK":                          reflect.ValueOf(constant.MakeFromLiteral("536900731", token.INT, 0)),
		"TIOCSCTTY":                         reflect.ValueOf(constant.MakeFromLiteral("536900705", token.INT, 0)),
		"TIOCSDRAINWAIT":                    reflect.ValueOf(constant.MakeFromLiteral("2147775575", token.INT, 0)),
		"TIOCSDTR":                          reflect.ValueOf(constant.MakeFromLiteral("536900729", token.INT, 0)),
		"TIOCSETA":                          reflect.ValueOf(constant.MakeFromLiteral("2150396948", token.INT, 0)),
		"TIOCSETAF":                         reflect.ValueOf(constant.MakeFromLiteral("2150396950", token.INT, 0)),
		"TIOCSETAW":                         reflect.ValueOf(constant.MakeFromLiteral("2150396949", token.INT, 0)),
		"TIOCSETD":                          reflect.ValueOf(constant.MakeFromLiteral("2147775515", token.INT, 0)),
		"TIOCSIG":                           reflect.ValueOf(constant.MakeFromLiteral("537162847", token.INT, 0)),
		"TIOCSPGRP":                         reflect.ValueOf(constant.MakeFromLiteral("2147775606", token.INT, 0)),
		"TIOCSTART":                         reflect.ValueOf(constant.MakeFromLiteral("536900718", token.INT, 0)),
		"TIOCSTAT":                          reflect.ValueOf(constant.MakeFromLiteral("536900709", token.INT, 0)),
		"TIOCSTI":                           reflect.ValueOf(constant.MakeFromLiteral("2147578994", token.INT, 0)),
		"TIOCSTOP":                          reflect.ValueOf(constant.MakeFromLiteral("536900719", token.INT, 0)),
		"TIOCSWINSZ":                        reflect.ValueOf(constant.MakeFromLiteral("2148037735", token.INT, 0)),
		"TIOCTIMESTAMP":                     reflect.ValueOf(constant.MakeFromLiteral("1074820185", token.INT, 0)),
		"TIOCUCNTL":                         reflect.ValueOf(constant.MakeFromLiteral("2147775590", token.INT, 0)),
		"TOSTOP":                            reflect.ValueOf(constant.MakeFromLiteral("4194304", token.INT, 0)),
		"TimespecToNsec":                    reflect.ValueOf(syscall.TimespecToNsec),
		"TimevalToNsec":                     reflect.ValueOf(syscall.TimevalToNsec),
		"Truncate":                          reflect.ValueOf(syscall.Truncate),
		"Umask":                             reflect.ValueOf(syscall.Umask),
		"Undelete":                          reflect.ValueOf(syscall.Undelete),
		"UnixRights":                        reflect.ValueOf(syscall.UnixRights),
		"Unlink":                            reflect.ValueOf(syscall.Unlink),
		"Unmount":                           reflect.ValueOf(syscall.Unmount),
		"Unsetenv":                          reflect.ValueOf(syscall.Unsetenv),
		"Utimes":                            reflect.ValueOf(syscall.Utimes),
		"UtimesNano":                        reflect.ValueOf(syscall.UtimesNano),
		"VDISCARD":                          reflect.ValueOf(constant.MakeFromLiteral("15", token.INT, 0)),
		"VDSUSP":                            reflect.ValueOf(constant.MakeFromLiteral("11", token.INT, 0)),
		"VEOF":                              reflect.ValueOf(constant.MakeFromLiteral("0", token.INT, 0)),
		"VEOL":                              reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"VEOL2":                             reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"VERASE":                            reflect.ValueOf(constant.MakeFromLiteral("3", token.INT, 0)),
		"VERASE2":                           reflect.ValueOf(constant.MakeFromLiteral("7", token.INT, 0)),
		"VINTR":                             reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"VKILL":                             reflect.ValueOf(constant.MakeFromLiteral("5", token.INT, 0)),
		"VLNEXT":                            reflect.ValueOf(constant.MakeFromLiteral("14", token.INT, 0)),
		"VMIN":                              reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"VQUIT":                             reflect.ValueOf(constant.MakeFromLiteral("9", token.INT, 0)),
		"VREPRINT":                          reflect.ValueOf(constant.MakeFromLiteral("6", token.INT, 0)),
		"VSTART":                            reflect.ValueOf(constant.MakeFromLiteral("12", token.INT, 0)),
		"VSTATUS":                           reflect.ValueOf(constant.MakeFromLiteral("18", token.INT, 0)),
		"VSTOP":                             reflect.ValueOf(constant.MakeFromLiteral("13", token.INT, 0)),
		"VSUSP":                             reflect.ValueOf(constant.MakeFromLiteral("10", token.INT, 0)),
		"VTIME":                             reflect.ValueOf(constant.MakeFromLiteral("17", token.INT, 0)),
		"VWERASE":                           reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"WCONTINUED":                        reflect.ValueOf(constant.MakeFromLiteral("4", token.INT, 0)),
		"WCOREFLAG":                         reflect.ValueOf(constant.MakeFromLiteral("128", token.INT, 0)),
		"WEXITED":                           reflect.ValueOf(constant.MakeFromLiteral("16", token.INT, 0)),
		"WLINUXCLONE":                       reflect.ValueOf(constant.MakeFromLiteral("2147483648", token.INT, 0)),
		"WNOHANG":                           reflect.ValueOf(constant.MakeFromLiteral("1", token.INT, 0)),
		"WNOWAIT":                           reflect.ValueOf(constant.MakeFromLiteral("8", token.INT, 0)),
		"WSTOPPED":                          reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"WTRAPPED":                          reflect.ValueOf(constant.MakeFromLiteral("32", token.INT, 0)),
		"WUNTRACED":                         reflect.ValueOf(constant.MakeFromLiteral("2", token.INT, 0)),
		"Wait4":                             reflect.ValueOf(syscall.Wait4),
		"Write":                             reflect.ValueOf(syscall.Write),

		// type definitions
		"BpfHdr":                        reflect.ValueOf((*syscall.BpfHdr)(nil)),
		"BpfInsn":                       reflect.ValueOf((*syscall.BpfInsn)(nil)),
		"BpfProgram":                    reflect.ValueOf((*syscall.BpfProgram)(nil)),
		"BpfStat":                       reflect.ValueOf((*syscall.BpfStat)(nil)),
		"BpfVersion":                    reflect.ValueOf((*syscall.BpfVersion)(nil)),
		"BpfZbuf":                       reflect.ValueOf((*syscall.BpfZbuf)(nil)),
		"BpfZbufHeader":                 reflect.ValueOf((*syscall.BpfZbufHeader)(nil)),
		"Cmsghdr":                       reflect.ValueOf((*syscall.Cmsghdr)(nil)),
		"Conn":                          reflect.ValueOf((*syscall.Conn)(nil)),
		"Credential":                    reflect.ValueOf((*syscall.Credential)(nil)),
		"Dirent":                        reflect.ValueOf((*syscall.Dirent)(nil)),
		"Errno":                         reflect.ValueOf((*syscall.Errno)(nil)),
		"FdSet":                         reflect.ValueOf((*syscall.FdSet)(nil)),
		"Flock_t":                       reflect.ValueOf((*syscall.Flock_t)(nil)),
		"Fsid":                          reflect.ValueOf((*syscall.Fsid)(nil)),
		"ICMPv6Filter":                  reflect.ValueOf((*syscall.ICMPv6Filter)(nil)),
		"IPMreq":                        reflect.ValueOf((*syscall.IPMreq)(nil)),
		"IPMreqn":                       reflect.ValueOf((*syscall.IPMreqn)(nil)),
		"IPv6MTUInfo":                   reflect.ValueOf((*syscall.IPv6MTUInfo)(nil)),
		"IPv6Mreq":                      reflect.ValueOf((*syscall.IPv6Mreq)(nil)),
		"IfAnnounceMsghdr":              reflect.ValueOf((*syscall.IfAnnounceMsghdr)(nil)),
		"IfData":                        reflect.ValueOf((*syscall.IfData)(nil)),
		"IfMsghdr":                      reflect.ValueOf((*syscall.IfMsghdr)(nil)),
		"IfaMsghdr":                     reflect.ValueOf((*syscall.IfaMsghdr)(nil)),
		"IfmaMsghdr":                    reflect.ValueOf((*syscall.IfmaMsghdr)(nil)),
		"Inet6Pktinfo":                  reflect.ValueOf((*syscall.Inet6Pktinfo)(nil)),
		"InterfaceAddrMessage":          reflect.ValueOf((*syscall.InterfaceAddrMessage)(nil)),
		"InterfaceAnnounceMessage":      reflect.ValueOf((*syscall.InterfaceAnnounceMessage)(nil)),
		"InterfaceMessage":              reflect.ValueOf((*syscall.InterfaceMessage)(nil)),
		"InterfaceMulticastAddrMessage": reflect.ValueOf((*syscall.InterfaceMulticastAddrMessage)(nil)),
		"Iovec":                         reflect.ValueOf((*syscall.Iovec)(nil)),
		"Kevent_t":                      reflect.ValueOf((*syscall.Kevent_t)(nil)),
		"Linger":                        reflect.ValueOf((*syscall.Linger)(nil)),
		"Msghdr":                        reflect.ValueOf((*syscall.Msghdr)(nil)),
		"ProcAttr":                      reflect.ValueOf((*syscall.ProcAttr)(nil)),
		"RawConn":                       reflect.ValueOf((*syscall.RawConn)(nil)),
		"RawSockaddr":                   reflect.ValueOf((*syscall.RawSockaddr)(nil)),
		"RawSockaddrAny":                reflect.ValueOf((*syscall.RawSockaddrAny)(nil)),
		"RawSockaddrDatalink":           reflect.ValueOf((*syscall.RawSockaddrDatalink)(nil)),
		"RawSockaddrInet4":              reflect.ValueOf((*syscall.RawSockaddrInet4)(nil)),
		"RawSockaddrInet6":              reflect.ValueOf((*syscall.RawSockaddrInet6)(nil)),
		"RawSockaddrUnix":               reflect.ValueOf((*syscall.RawSockaddrUnix)(nil)),
		"Rlimit":                        reflect.ValueOf((*syscall.Rlimit)(nil)),
		"RouteMessage":                  reflect.ValueOf((*syscall.RouteMessage)(nil)),
		"RoutingMessage":                reflect.ValueOf((*syscall.RoutingMessage)(nil)),
		"RtMetrics":                     reflect.ValueOf((*syscall.RtMetrics)(nil)),
		"RtMsghdr":                      reflect.ValueOf((*syscall.RtMsghdr)(nil)),
		"Rusage":                        reflect.ValueOf((*syscall.Rusage)(nil)),
		"Signal":                        reflect.ValueOf((*syscall.Signal)(nil)),
		"Sockaddr":                      reflect.ValueOf((*syscall.Sockaddr)(nil)),
		"SockaddrDatalink":              reflect.ValueOf((*syscall.SockaddrDatalink)(nil)),
		"SockaddrInet4":                 reflect.ValueOf((*syscall.SockaddrInet4)(nil)),
		"SockaddrInet6":                 reflect.ValueOf((*syscall.SockaddrInet6)(nil)),
		"SockaddrUnix":                  reflect.ValueOf((*syscall.SockaddrUnix)(nil)),
		"SocketControlMessage":          reflect.ValueOf((*syscall.SocketControlMessage)(nil)),
		"Stat_t":                        reflect.ValueOf((*syscall.Stat_t)(nil)),
		"Statfs_t":                      reflect.ValueOf((*syscall.Statfs_t)(nil)),
		"SysProcAttr":                   reflect.ValueOf((*syscall.SysProcAttr)(nil)),
		"Termios":                       reflect.ValueOf((*syscall.Termios)(nil)),
		"Timespec":                      reflect.ValueOf((*syscall.Timespec)(nil)),
		"Timeval":                       reflect.ValueOf((*syscall.Timeval)(nil)),
		"WaitStatus":                    reflect.ValueOf((*syscall.WaitStatus)(nil)),

		// interface wrapper definitions
		"_Conn":           reflect.ValueOf((*_syscall_Conn)(nil)),
		"_RawConn":        reflect.ValueOf((*_syscall_RawConn)(nil)),
		"_RoutingMessage": reflect.ValueOf((*_syscall_RoutingMessage)(nil)),
		"_Sockaddr":       reflect.ValueOf((*_syscall_Sockaddr)(nil)),
	}
}

// _syscall_Conn is an interface wrapper for Conn type
type _syscall_Conn struct {
	IValue       interface{}
	WSyscallConn func() (syscall.RawConn, error)
}

func (W _syscall_Conn) SyscallConn() (syscall.RawConn, error) { return W.WSyscallConn() }

// _syscall_RawConn is an interface wrapper for RawConn type
type _syscall_RawConn struct {
	IValue   interface{}
	WControl func(f func(fd uintptr)) error
	WRead    func(f func(fd uintptr) (done bool)) error
	WWrite   func(f func(fd uintptr) (done bool)) error
}

func (W _syscall_RawConn) Control(f func(fd uintptr)) error           { return W.WControl(f) }
func (W _syscall_RawConn) Read(f func(fd uintptr) (done bool)) error  { return W.WRead(f) }
func (W _syscall_RawConn) Write(f func(fd uintptr) (done bool)) error { return W.WWrite(f) }

// _syscall_RoutingMessage is an interface wrapper for RoutingMessage type
type _syscall_RoutingMessage struct {
	IValue interface{}
}

// _syscall_Sockaddr is an interface wrapper for Sockaddr type
type _syscall_Sockaddr struct {
	IValue interface{}
}
